@@ -28,6 +28,8 @@ BOOL APIENTRY About(HWND, unsigned int, unsigned int, long);
 #include <osi.h>
 #include <afs/vldbint.h>
 #include <afs/afsint.h>
+#define FSINT_COMMON_XG
+
 #include <afs/prs_fs.h>
 
 #include "cm_config.h"
@@ -51,13 +53,12 @@ BOOL APIENTRY About(HWND, unsigned int, unsigned int, long);
 #include "cm_btree.h"
 #include "cm_daemon.h"
 #include "cm_ioctl.h"
+#include "smb_iocons.h"
 #include "cm_dnlc.h"
 #include "cm_buf.h"
 #include "cm_memmap.h"
 #include "cm_freelance.h"
 #include "cm_performance.h"
-#include "smb_ioctl.h"
-#include "smb_iocons.h"
 #include "afsd_init.h"
 #include "afsd_eventlog.h"
 
