@@ -9,6 +9,7 @@
 
 #include <afs/param.h>
 #include <afs/stds.h>
+#include <afs/com_err.h>
 
 #include <windows.h>
 #include <stdlib.h>
@@ -44,10 +45,11 @@ static int rxInitDone = 0;
 
 void Die();
 
+#if 0
 foldcmp (a, b)
-    register char *a;
-    register char *b; {
-    register char t, u;
+    char *a;
+    char *b; {
+    char t, u;
     while (1) {
         t = *a++;
         u = *b++;
@@ -57,18 +59,19 @@ foldcmp (a, b)
         if (t == 0) return 0;
     }
 }
+#endif
 
 /* this function returns TRUE (1) if the file is in AFS, otherwise false (0) */
-static int InAFS(register char *apath)
+static int InAFS(char *apath)
 {
     struct ViceIoctl blob;
-    register afs_int32 code;
+    afs_int32 code;
 
     blob.in_size = 0;
     blob.out_size = MAXSIZE;
     blob.out = space;
 
-    code = pioctl(apath, VIOC_FILE_CELL_NAME, &blob, 1);
+    code = pioctl_utf8(apath, VIOC_FILE_CELL_NAME, &blob, 1);
     if (code) {
 	if ((errno == EINVAL) || (errno == ENOENT)) 
             return 0;
@@ -86,9 +89,9 @@ IsFreelanceRoot(char *apath)
     blob.out_size = MAXSIZE;
     blob.out = space;
 
-    code = pioctl(apath, VIOC_FILE_CELL_NAME, &blob, 1);
+    code = pioctl_utf8(apath, VIOC_FILE_CELL_NAME, &blob, 1);
     if (code == 0)
-        return !strcmp("Freelance.Local.Root",space);
+        return !stricmp("Freelance.Local.Root",space);
     return 1;   /* assume it is because it is more restrictive that way */
 }
 
@@ -101,7 +104,7 @@ static const char * NetbiosName(void)
     DWORD enabled = 0;
 
     code = RegOpenKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_SVC_PARAM_SUBKEY,
-                         0, KEY_QUERY_VALUE, &parmKey);
+                         0, (IsWow64()?KEY_WOW64_64KEY:0)|KEY_QUERY_VALUE, &parmKey);
     if (code == ERROR_SUCCESS) {
         dummyLen = sizeof(buffer);
         code = RegQueryValueEx(parmKey, "NetbiosName", NULL, NULL,
@@ -255,7 +258,7 @@ static BOOL IsAdmin (void)
 /* return a static pointer to a buffer */
 static char *Parent(apath)
 char *apath; {
-    register char *tp;
+    char *tp;
     strcpy(tspace, apath);
     tp = strrchr(tspace, '\\');
     if (tp) {
@@ -269,16 +272,16 @@ char *apath; {
 }
 
 
-static ListLinkCmd(as)
-register struct cmd_syndesc *as; {
-    register afs_int32 code;
+static ListLinkCmd(struct cmd_syndesc *as, void *arock)
+{
+    afs_int32 code;
     struct ViceIoctl blob;
     int error;
-    register struct cmd_item *ti;
+    struct cmd_item *ti;
     char orig_name[1024];		/*Original name, may be modified*/
     char true_name[1024];		/*``True'' dirname (e.g., symlink target)*/
     char parent_dir[1024];		/*Parent directory of true name*/
-    register char *last_component;	/*Last component of true name*/
+    char *last_component;	/*Last component of true name*/
 #ifndef WIN32
     struct stat statbuff;		/*Buffer for status info*/
 #endif /* not WIN32 */
@@ -399,7 +402,7 @@ register struct cmd_syndesc *as; {
 	blob.out = space;
 	memset(space, 0, MAXSIZE);
 
-	code = pioctl(parent_dir, VIOC_LISTSYMLINK, &blob, 1);
+	code = pioctl_utf8(parent_dir, VIOC_LISTSYMLINK, &blob, 1);
 
 	if (code == 0)
 	    printf("'%s' is a %ssymlink to '%s'\n",
@@ -420,9 +423,9 @@ register struct cmd_syndesc *as; {
     return error;
 }
 
-static MakeLinkCmd(as)
-register struct cmd_syndesc *as; {
-    register afs_int32 code;
+static MakeLinkCmd(struct cmd_syndesc *as, void *arock)
+{
+    afs_int32 code;
     struct ViceIoctl blob;
     char * parent;
     char path[1024] = "";
@@ -460,6 +463,8 @@ register struct cmd_syndesc *as; {
 	return 1;
     }
 
+    fprintf(stderr, "Creating symlink [%s] to [%s]\n", path, as->parms[1].items->data);
+
     /* create symlink with a special pioctl for Windows NT, since it doesn't
      * have a symlink system call.
      */
@@ -467,7 +472,7 @@ register struct cmd_syndesc *as; {
     blob.in_size = 1 + (long)strlen(as->parms[1].items->data);
     blob.in = as->parms[1].items->data;
     blob.out = NULL;
-    code = pioctl(path, VIOC_SYMLINK, &blob, 0);
+    code = pioctl_utf8(path, VIOC_SYMLINK, &blob, 0);
 #else /* not WIN32 */
     code = symlink(as->parms[1].items->data, path);
 #endif /* not WIN32 */
@@ -484,14 +489,14 @@ register struct cmd_syndesc *as; {
  *	    symlink (or ``.'' if none is provided)
  *      tp: Set to point to the actual name of the symlink to nuke.
  */
-static RemoveLinkCmd(as)
-register struct cmd_syndesc *as; {
-    register afs_int32 code=0;
+static RemoveLinkCmd(struct cmd_syndesc *as, void *arock)
+{
+    afs_int32 code=0;
     struct ViceIoctl blob;
-    register struct cmd_item *ti;
+    struct cmd_item *ti;
     char tbuffer[1024];
     char lsbuffer[1024];
-    register char *tp;
+    char *tp;
     
     for(ti=as->parms[0].items; ti; ti=ti->next) {
 	/* once per file */
@@ -528,7 +533,7 @@ register struct cmd_syndesc *as; {
 	blob.in_size = (int)strlen(tp)+1;
 	blob.out = lsbuffer;
 	blob.out_size = sizeof(lsbuffer);
-	code = pioctl(tbuffer, VIOC_LISTSYMLINK, &blob, 0);
+	code = pioctl_utf8(tbuffer, VIOC_LISTSYMLINK, &blob, 0);
 	if (code) {
 	    if (errno == EINVAL)
 		fprintf(stderr,"symlink: '%s' is not a symlink.\n", ti->data);
@@ -547,7 +552,7 @@ register struct cmd_syndesc *as; {
 	blob.out_size = 0;
 	blob.in = tp;
 	blob.in_size = (long)strlen(tp)+1;
-	code = pioctl(tbuffer, VIOC_DELSYMLINK, &blob, 0);
+	code = pioctl_utf8(tbuffer, VIOC_DELSYMLINK, &blob, 0);
 	if (code) {
 	    Die(errno, ti->data);
 	}
@@ -555,14 +560,58 @@ register struct cmd_syndesc *as; {
     return code;
 }
 
+static void
+FreeUtf8CmdLine(int argc, char ** argv)
+{
+    int i;
+    for (i=0; i < argc; i++) {
+        if (argv[i])
+            free(argv[i]);
+    }
+    free(argv);
+}
+
+static char **
+MakeUtf8Cmdline(int argc, const wchar_t **wargv)
+{
+    char ** argv;
+    int i;
+
+    argv = calloc(argc, sizeof(argv[0]));
+    if (argv == NULL)
+        return NULL;
+
+    for (i=0; i < argc; i++) {
+        int s;
+
+        s = WideCharToMultiByte(CP_UTF8, 0, wargv[i], -1, NULL, 0, NULL, FALSE);
+        if (s == 0 ||
+            (argv[i] = calloc(s+1, sizeof(char))) == NULL) {
+            break;
+        }
+
+        s = WideCharToMultiByte(CP_UTF8, 0, wargv[i], -1, argv[i], s+1, NULL, FALSE);
+        if (s == 0) {
+            break;
+        }
+    }
+
+    if (i < argc) {
+        FreeUtf8CmdLine(argc, argv);
+        return NULL;
+    }
+
+    return argv;
+}
+
 static    struct ViceIoctl gblob;
 static int debug = 0;
 
-main(argc, argv)
-int argc;
-char **argv; {
-    register afs_int32 code;
-    register struct cmd_syndesc *ts;
+int wmain(int argc, wchar_t **wargv)
+{
+    afs_int32 code;
+    struct cmd_syndesc *ts;
+    char ** argv;
     
 #ifdef	AFS_AIX32_ENV
     /*
@@ -586,17 +635,18 @@ char **argv; {
 
     /* try to find volume location information */
     
+    argv = MakeUtf8Cmdline(argc, wargv);
 
     osi_Init();
 
-    ts = cmd_CreateSyntax("list", ListLinkCmd, 0, "list symlink");    
+    ts = cmd_CreateSyntax("list", ListLinkCmd, NULL, "list symlink");    
     cmd_AddParm(ts, "-name", CMD_LIST, 0, "name");
     
-    ts = cmd_CreateSyntax("make", MakeLinkCmd, 0, "make symlink");
+    ts = cmd_CreateSyntax("make", MakeLinkCmd, NULL, "make symlink");
     cmd_AddParm(ts, "-name", CMD_SINGLE, 0, "name");
     cmd_AddParm(ts, "-to", CMD_SINGLE, 0, "target");
 
-    ts = cmd_CreateSyntax("remove", RemoveLinkCmd, 0, "remove symlink");
+    ts = cmd_CreateSyntax("remove", RemoveLinkCmd, NULL, "remove symlink");
     cmd_AddParm(ts, "-name", CMD_LIST, 0, "name");
     cmd_CreateAlias(ts, "rm");
 
@@ -606,6 +656,8 @@ char **argv; {
     if (rxInitDone) rx_Finalize();
 #endif /* not WIN32 */
     
+    FreeUtf8CmdLine(argc, argv);
+    
     return code;
 }
 
@@ -620,8 +672,12 @@ void Die(code, filename)
 	else fprintf(stderr,"%s: Invalid argument.\n", pn);
     }
     else if (code == ENOENT) {
-	if (filename) fprintf(stderr,"%s: File '%s' doesn't exist\n", pn, filename);
-	else fprintf(stderr,"%s: no such file returned\n", pn);
+	if (filename) fprintf(stderr,"%s: File '%s' doesn't exist.\n", pn, filename);
+	else fprintf(stderr,"%s: no such file returned.\n", pn);
+    }
+    else if (code == EEXIST) {
+	if (filename) fprintf(stderr,"%s: File '%s' already exists.\n", pn, filename);
+	else fprintf(stderr,"%s: the specified file already exists.\n", pn);
     }
     else if (code == EROFS)  fprintf(stderr,"%s: You can not change a backup or readonly volume\n", pn);
     else if (code == EACCES || code == EPERM) {
