@@ -11,6 +11,9 @@
  * INCLUDES _________________________________________________________________
  *
  */
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
