@@ -7,9 +7,13 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
+#include <afs/cm.h>
 #include <rx/rxkad.h>
 #include <afs/cm_config.h>
 }
@@ -659,8 +663,19 @@ BOOL fIsCellInCellServDB (LPCTSTR pszCell)
 {
    BOOL fFound = FALSE;
    CELLSERVDB CellServDB;
+   char cellname[256], i;
 
-   if (CSDB_ReadFile (&CellServDB, NULL))
+   /* we pray for all ascii cellnames */
+   for ( i=0 ; pszCell[i] && i < (sizeof(cellname)-1) ; i++ )
+       cellname[i] = pszCell[i];
+   cellname[i] = '\0';
+
+   ULONG code = cm_SearchCellRegistry(1, cellname, NULL, NULL, NULL, NULL);
+   if (code == 0)
+      fFound = TRUE;
+   if (!fFound && 
+       (code != CM_ERROR_FORCE_DNS_LOOKUP) && 
+       CSDB_ReadFile (&CellServDB, NULL))
    {
        if (CSDB_FindCell (&CellServDB, pszCell))
            fFound = TRUE;
@@ -669,16 +684,11 @@ BOOL fIsCellInCellServDB (LPCTSTR pszCell)
 #ifdef AFS_AFSDB_ENV
     if ( fFound == FALSE ) {
         int ttl;
-        char cellname[128], i;
-
-        /* we pray for all ascii cellnames */
-        for ( i=0 ; pszCell[i] && i < (sizeof(cellname)-1) ; i++ )
-            cellname[i] = pszCell[i];
-        cellname[i] = '\0';
-
         fFound = !cm_SearchCellByDNS(cellname, NULL, &ttl, NULL, NULL);
     }
 #endif
+     done:
+
    return fFound;
 }
 
