@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_file.c,v 1.12.2.2 2006/11/09 23:30:53 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -133,7 +131,7 @@ VnodeToDev(vnode_t avp)
 }
 
 void *
-osi_UFSOpen(afs_int32 ainode)
+osi_UFSOpen(afs_dcache_id_t *ainode)
 {
     struct vnode *vp;
     struct vattr va;
@@ -141,6 +139,9 @@ osi_UFSOpen(afs_int32 ainode)
     extern int cacheDiskType;
     afs_int32 code = 0;
     int dummy;
+    char fname[1024];
+    struct osi_stat tstat;
+
     AFS_STATCNT(osi_UFSOpen);
     if (cacheDiskType != AFS_FCACHE_TYPE_UFS) {
 	osi_Panic("UFSOpen called for non-UFS cache\n");
@@ -154,17 +155,40 @@ osi_UFSOpen(afs_int32 ainode)
     }
     afile = (struct osi_file *)osi_AllocSmallSpace(sizeof(struct osi_file));
     AFS_GUNLOCK();
+#ifdef AFS_CACHE_VNODE_PATH
+    if (ainode->ufs < 0) {
+	switch (ainode->ufs) {
+	case AFS_CACHE_CELLS_INODE:
+	    snprintf(fname, 1024, "%s/%s", afs_cachebasedir, "CellItems");
+	    break;
+	case AFS_CACHE_ITEMS_INODE:
+	    snprintf(fname, 1024, "%s/%s", afs_cachebasedir, "CacheItems");
+	    break;
+	case AFS_CACHE_VOLUME_INODE:
+	    snprintf(fname, 1024, "%s/%s", afs_cachebasedir, "VolumeItems");
+	    break;
+	default:
+	    osi_Panic("Invalid negative inode");
+	}
+    } else {
+	dummy = ainode->ufs / afs_numfilesperdir;
+	snprintf(fname, 1024, "%s/D%d/V%d", afs_cachebasedir, dummy, ainode->ufs);
+    }
+
+    code = vnode_open(fname, O_RDWR, 0, 0, &vp, afs_osi_ctxtp);
+#else
 #ifndef AFS_DARWIN80_ENV
     if (afs_CacheFSType == AFS_APPL_HFS_CACHE)
-	code = igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, &ainode, &vp, &va, &dummy);	/* XXX hfs is broken */
+	code = igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, &ainode->ufs, &vp, &va, &dummy);	/* XXX hfs is broken */
     else if (afs_CacheFSType == AFS_APPL_UFS_CACHE)
 #endif
 	code =
-	    igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, (ino_t) ainode,
+	    igetinode(afs_cacheVfsp, (dev_t) cacheDev.dev, (ino_t) ainode->ufs,
 		      &vp, &va, &dummy);
 #ifndef AFS_DARWIN80_ENV
     else
 	panic("osi_UFSOpen called before cacheops initialized\n");
+#endif
 #endif
     AFS_GLOCK();
     if (code) {
@@ -172,10 +196,15 @@ osi_UFSOpen(afs_int32 ainode)
 	osi_Panic("UFSOpen: igetinode failed");
     }
     afile->vnode = vp;
-    afile->size = va.va_size;
     afile->offset = 0;
     afile->proc = (int (*)())0;
-    afile->inum = ainode;	/* for hint validity checking */
+    afile->inum = ainode->ufs;	/* for hint validity checking */
+#ifndef AFS_CACHE_VNODE_PATH
+    afile->size = va.va_size;
+#else
+    code = afs_osi_Stat(afile, &tstat);
+    afile->size = tstat.size;
+#endif
     return (void *)afile;
 }
 
@@ -387,8 +416,6 @@ afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 void
 shutdown_osifile(void)
 {
-    extern int afs_cold_shutdown;
-
     AFS_STATCNT(shutdown_osifile);
     if (afs_cold_shutdown) {
 	afs_osicred_initialized = 0;
