@@ -14,20 +14,19 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.44.4.6 2008/07/01 03:35:23 shadow Exp $");
 
 #include <linux/module.h> /* early to avoid printf->printk mapping */
+#if defined(AFS_LINUX26_ENV)
+#include "h/dcache.h"
+#include "h/namei.h"
+#include "h/kthread.h"
+#endif
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
 #include "afs/afs_stats.h"
 #if defined(AFS_LINUX24_ENV)
 #include "h/smp_lock.h"
 #endif
-#if defined(AFS_LINUX26_ENV)
-#include "h/namei.h"
-#include "h/kthread.h"
-#endif
 
 int afs_osicred_initialized = 0;
 struct AFS_UCRED afs_osi_cred;
@@ -113,9 +112,10 @@ osi_lookupname_internal(char *aname, int followlink, struct vfsmount **mnt,
     }
     return code;
 }
+
 int
 osi_lookupname(char *aname, uio_seg_t seg, int followlink, 
-			struct dentry **dpp)
+	       struct dentry **dpp)
 {
     int code;
     char *tname;
