@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.74.2.10 2008/09/22 19:35:26 shadow Exp $");
 
 #include <linux/module.h> /* early to avoid printf->printk mapping */
 #include "afs/sysincludes.h"
@@ -66,7 +64,7 @@ init_module(void)
 #endif
 {
     int err;
-    RWLOCK_INIT(&afs_xosi, "afs_xosi");
+    AFS_RWLOCK_INIT(&afs_xosi, "afs_xosi");
 
 #if !defined(AFS_LINUX24_ENV)
     /* obtain PAGE_OFFSET value */
@@ -88,18 +86,24 @@ init_module(void)
 #endif
 #endif
 
+#ifndef LINUX_KEYRING_SUPPORT
     err = osi_syscall_init();
     if (err)
 	return err;
+#endif
     err = afs_init_inodecache();
     if (err) {
+#ifndef LINUX_KEYRING_SUPPORT
 	osi_syscall_clean();
+#endif
 	return err;
     }
     err = register_filesystem(&afs_fs_type);
     if (err) {
 	afs_destroy_inodecache();
+#ifndef LINUX_KEYRING_SUPPORT
 	osi_syscall_clean();
+#endif
 	return err;
     }
 
@@ -132,7 +136,9 @@ cleanup_module(void)
     osi_keyring_shutdown();
 #endif
     osi_sysctl_clean();
+#ifndef LINUX_KEYRING_SUPPORT
     osi_syscall_clean();
+#endif
     unregister_filesystem(&afs_fs_type);
 
     afs_destroy_inodecache();
