@@ -14,10 +14,10 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_nfssrv.c,v 1.1.2.3 2006/08/11 21:40:56 shadow Exp $");
 
+#if !defined(AFS_NONFSTRANS) || defined(AFS_AIX_IAUTH_ENV)
 #include <linux/module.h> /* early to avoid printf->printk mapping */
+#include <linux/fs.h>
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
 #include "nfsclient.h"
@@ -26,7 +26,7 @@ RCSID
 #include <linux/sunrpc/svcauth.h>
 
 static unsigned long authtab_addr = 0;
-#if defined(module_param)
+#if defined(module_param) && LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
 module_param(authtab_addr, long, 0);
 #else
 MODULE_PARM(authtab_addr, "l");
@@ -95,6 +95,7 @@ svcauth_afs_accept(struct svc_rqst *rqstp, u32 *authp)
     struct nfs_server_thread *ns;
     struct afs_exporter *outexp;
     struct AFS_UCRED *credp;
+    struct sockaddr_in *addr;
     int code;
 
     code = afs_orig_authtab[rqstp->rq_authop->flavour]->accept(rqstp, authp);
@@ -108,11 +109,16 @@ svcauth_afs_accept(struct svc_rqst *rqstp, u32 *authp)
 	/* XXX maybe we should fail this with rpc_system_err? */
 	return SVC_OK;
     }
+#if HAVE_SVC_ADDR_IN
+    addr = svc_addr_in(rqstp);
+#else
+    addr = &rqstp->rq_addr;
+#endif
 
     ns->active		= 1;
     ns->flavor		= rqstp->rq_authop->flavour;
     ns->code		= EACCES;
-    ns->client_addr	= rqstp->rq_addr;
+    ns->client_addr	= *addr;
     ns->client_addrlen	= rqstp->rq_addrlen;
     ns->client_uid	= rqstp->rq_cred.cr_uid;
     ns->client_gid	= rqstp->rq_cred.cr_gid;
@@ -125,10 +131,9 @@ svcauth_afs_accept(struct svc_rqst *rqstp, u32 *authp)
     else
 	ns->client_g1	= -1;
 
-    /* NB: Don't check the length; it's not always filled in! */
-    if (rqstp->rq_addr.sin_family != AF_INET) {
+    if (addr->sin_family != AF_INET) {
 	printk("afs: NFS request from non-IPv4 client (family %d len %d)\n",
-	       rqstp->rq_addr.sin_family, rqstp->rq_addrlen);
+	       addr->sin_family, rqstp->rq_addrlen);
 	goto done;
     }
 
@@ -142,7 +147,7 @@ svcauth_afs_accept(struct svc_rqst *rqstp, u32 *authp)
      * clients to afs_nobody */
     if (credp->cr_uid == -1)
 	credp->cr_uid = -2;
-    code = afs_nfsclient_reqhandler(0, &credp, rqstp->rq_addr.sin_addr.s_addr,
+    code = afs_nfsclient_reqhandler(0, &credp, addr->sin_addr.s_addr,
 				    &ns->uid, &outexp);
     if (!code && outexp) EXP_RELE(outexp);
     if (!code) ns->code = 0;
@@ -197,9 +202,10 @@ void osi_linux_nfssrv_init(void)
     int i;
 
     nfssrv_list = 0;
-    RWLOCK_INIT(&afs_xnfssrv, "afs_xnfssrv");
+    AFS_RWLOCK_INIT(&afs_xnfssrv, "afs_xnfssrv");
 
-    if (authtab)	   afs_authtab = authtab;
+    if (authtab && !IS_ERR(authtab))
+	   afs_authtab = authtab;
     else if (authtab_addr) afs_authtab = (struct auth_ops **)authtab_addr;
     else {
 	printk("Warning: Unable to find the address of authtab\n");
@@ -253,3 +259,5 @@ void osi_linux_nfssrv_shutdown(void)
     ReleaseWriteLock(&afs_xnfssrv);
     AFS_GUNLOCK();
 }
+#endif /* AFS_NONFSTRANS */
+
