@@ -16,7 +16,7 @@
  * afs_osi.h.
  */
 
-/* $Id: osi_machdep.h,v 1.27.2.2 2009/01/22 21:29:08 shadow Exp $ */
+/* $Id$ */
 
 #ifndef _OSI_MACHDEP_H_
 #define _OSI_MACHDEP_H_
@@ -98,7 +98,7 @@ extern void osi_obsd_Free(void *p, size_t asize);
 /* time */
 #define	afs_hz		hz
 #define osi_GetTime(x)	microtime(x)
-#define osi_Time()	(time.tv_sec)
+extern time_t osi_Time();
 
 /* str */
 #define afs_strcasecmp(s1, s2)	strncasecmp((s1), (s2), 65535)
@@ -132,6 +132,10 @@ extern int afs_vget();
 #define	gop_lookupname(fnamep, segflg, followlink, compvpp) \
 	afs_nbsd_lookupname((fnamep), (segflg), (followlink), (compvpp))
 
+#undef gop_lookupname_user
+#define	gop_lookupname_user(fnamep, segflg, followlink, compvpp) \
+	afs_nbsd_lookupname((fnamep), (segflg), (followlink), (compvpp))
+
 #ifdef AFS_OBSD39_ENV
 #define afs_osi_lockmgr(l, f, i, p) lockmgr((l), (f), (i))
 #else
