@@ -1,3 +1,4 @@
+
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
@@ -14,20 +15,18 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/UKERNEL/afs_usrops.c,v 1.30.6.12 2009/01/26 18:52:42 shadow Exp $");
-
-
 #ifdef	UKERNEL
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include <net/if.h>
+
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs_usrops.h"
 #include "afs/afs_stats.h"
 #include "afs/auth.h"
 #include "afs/cellconfig.h"
 #include "afs/vice.h"
+#include "afs/kauth.h"
 #include "afs/kautils.h"
 #include "afs/afsutil.h"
 #include "rx/rx_globals.h"
@@ -100,8 +99,6 @@ int missing_CellInfoFile = 1;
 struct afs_cacheParams cparams;	/* params passed to cache manager */
 struct afsconf_dir *afs_cdir;	/* config dir */
 
-static int HandleMTab();
-
 int afs_bufferpages = 100;
 int usr_udpcksum = 0;
 
@@ -141,6 +138,7 @@ pthread_cond_t usr_sleep_cond;
 #endif /* !NETSCAPE_NSAPI */
 
 int call_syscall(long, long, long, long, long, long);
+int fork_syscall(long, long, long, long, long, long);
 
 
 /*
@@ -701,7 +699,7 @@ lookupname(char *fnamep, int segflg, int followlink,
  * open a file given its i-node number
  */
 void *
-osi_UFSOpen(afs_int32 ino)
+osi_UFSOpen(afs_dcache_id_t *ino)
 {
     int rc;
     struct osi_file *fp;
@@ -709,7 +707,7 @@ osi_UFSOpen(afs_int32 ino)
 
     AFS_ASSERT_GLOCK();
 
-    if (ino > n_osi_files) {
+    if (ino->ufs > n_osi_files) {
 	u.u_error = ENOENT;
 	return NULL;
     }
@@ -717,7 +715,7 @@ osi_UFSOpen(afs_int32 ino)
     AFS_GUNLOCK();
     fp = (struct osi_file *)afs_osi_Alloc(sizeof(struct osi_file));
     usr_assert(fp != NULL);
-    fp->fd = open(osi_file_table[ino - 1].name, O_RDWR | O_CREAT, 0);
+    fp->fd = open(osi_file_table[ino->ufs - 1].name, O_RDWR | O_CREAT, 0);
     if (fp->fd < 0) {
 	u.u_error = errno;
 	afs_osi_Free((char *)fp, sizeof(struct osi_file));
@@ -733,7 +731,7 @@ osi_UFSOpen(afs_int32 ino)
     }
     fp->size = st.st_size;
     fp->offset = 0;
-    fp->inum = ino;
+    fp->inum = ino->ufs;
     fp->vnode = (struct usr_vnode *)fp;
 
     AFS_GLOCK();
@@ -783,7 +781,6 @@ int
 afs_osi_Read(struct osi_file *fp, int offset, void *buf, afs_int32 len)
 {
     int rc, ret;
-    int code;
     struct stat st;
 
     AFS_ASSERT_GLOCK();
@@ -822,7 +819,6 @@ int
 afs_osi_Write(struct osi_file *fp, afs_int32 offset, void *buf, afs_int32 len)
 {
     int rc, ret;
-    int code;
     struct stat st;
 
     AFS_ASSERT_GLOCK();
@@ -913,13 +909,6 @@ afs_osi_VOP_RDWR(struct usr_vnode *vnodeP, struct usr_uio *uioP, int rw,
     return 0;
 }
 
-/*
- * Use malloc/free routines with check patterns before and after each block
- */
-
-static char *afs_check_string1 = "UAFS";
-static char *afs_check_string2 = "AFS_OSI_";
-
 void *
 afs_osi_Alloc(size_t size)
 {
@@ -1033,7 +1022,7 @@ osi_Active(struct vcache *avc)
 }
 
 int
-afs_osi_MapStrategy(int (*aproc) (), struct usr_buf *bp)
+afs_osi_MapStrategy(int (*aproc) (struct usr_buf *), struct usr_buf *bp)
 {
     afs_int32 returnCode;
     returnCode = (*aproc) (bp);
@@ -1080,8 +1069,6 @@ void
 osi_Init(void)
 {
     int i;
-    int rc;
-    usr_thread_t tid;
 
     /*
      * Allocate the table used to implement psuedo-inodes.
@@ -1314,8 +1301,13 @@ SweepAFSCache(int *vFilesFound)
     for (currp = readdir(cdirp); currp; currp = readdir(cdirp)) {
 	if (afsd_debug) {
 	    printf("%s: Current directory entry:\n", rn);
+#if defined(AFS_USR_DFBSD_ENV)
+	    printf("\tinode=%d, name='%s'\n", currp->d_ino,
+		   currp->d_name);
+#else
 	    printf("\tinode=%d, reclen=%d, name='%s'\n", currp->d_ino,
 		   currp->d_reclen, currp->d_name);
+#endif
 	}
 
 	/*
@@ -1472,8 +1464,6 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
 	  int nDaemonsParam, int cacheFlagsParam, char *logFile)
 {
     int st;
-    struct usr_proc *procp;
-    struct usr_ucred *ucredp;
     int i;
     int rc;
     int currVFile;		/* Current AFS cache file number */
@@ -1481,8 +1471,6 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
     int cacheIteration;		/* cache verification loop counter */
     int vFilesFound;		/* Num data cache files found in sweep */
     FILE *logfd;
-    afs_int32 vfs1_type = -1;
-    struct afs_ioctl iob;
     char tbuffer[1024];
     char *p;
     char lastchar;
@@ -1660,8 +1648,9 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
     }
     memset(pathname_for_V, 0, (cacheFiles * sizeof(char *)));
     if (afsd_debug)
-	printf("%s: %d pathname_for_V entries at 0x%x, %d bytes\n", rn,
-	       cacheFiles, pathname_for_V, (cacheFiles * sizeof(AFSD_INO_T)));
+	printf("%s: %d pathname_for_V entries at %" AFS_PTR_FMT
+	       ", %lud bytes\n", rn, cacheFiles, pathname_for_V,
+	       afs_printable_uint32_lu(cacheFiles * sizeof(AFSD_INO_T)));
 
     /*
      * Set up all the pathnames we'll need for later.
@@ -1695,21 +1684,21 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
      */
     if (afsd_debug)
 	printf("%s: Calling AFSOP_RXLISTENER_DAEMON\n", rn);
-    fork_syscall(AFSCALL_CALL, AFSOP_RXLISTENER_DAEMON, FALSE, FALSE, FALSE);
+    fork_syscall(AFSCALL_CALL, AFSOP_RXLISTENER_DAEMON, FALSE, FALSE, FALSE, 0);
 
     if (afsd_verbose)
 	printf("%s: Forking rx callback listener.\n", rn);
     /* Child */
     if (preallocs < cacheStatEntries + 50)
 	preallocs = cacheStatEntries + 50;
-    fork_syscall(AFSCALL_CALL, AFSOP_START_RXCALLBACK, preallocs);
+    fork_syscall(AFSCALL_CALL, AFSOP_START_RXCALLBACK, preallocs, 0, 0, 0);
 
     /*
      * Start the RX event handler.
      */
     if (afsd_debug)
 	printf("%s: Calling AFSOP_RXEVENT_DAEMON\n", rn);
-    fork_syscall(AFSCALL_CALL, AFSOP_RXEVENT_DAEMON, FALSE);
+    fork_syscall(AFSCALL_CALL, AFSOP_RXEVENT_DAEMON, FALSE, 0, 0, 0);
 
     /*
      * Set up all the kernel processes needed for AFS.
@@ -1816,16 +1805,16 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
 
     if (afsd_verbose)
 	printf("%s: Forking AFS daemon.\n", rn);
-    fork_syscall(AFSCALL_CALL, AFSOP_START_AFS);
+    fork_syscall(AFSCALL_CALL, AFSOP_START_AFS, 0, 0, 0, 0);
 
     if (afsd_verbose)
 	printf("%s: Forking check server daemon.\n", rn);
-    fork_syscall(AFSCALL_CALL, AFSOP_START_CS);
+    fork_syscall(AFSCALL_CALL, AFSOP_START_CS, 0, 0, 0, 0);
 
     if (afsd_verbose)
 	printf("%s: Forking %d background daemons.\n", rn, nDaemons);
     for (i = 0; i < nDaemons; i++) {
-	fork_syscall(AFSCALL_CALL, AFSOP_START_BKG);
+	fork_syscall(AFSCALL_CALL, AFSOP_START_BKG, 0, 0, 0, 0);
     }
 
     if (afsd_verbose)
@@ -1901,7 +1890,7 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
 
     if (afsd_verbose)
 	printf("%s: Forking trunc-cache daemon.\n", rn);
-    fork_syscall(AFSCALL_CALL, AFSOP_START_TRUNCDAEMON);
+    fork_syscall(AFSCALL_CALL, AFSOP_START_TRUNCDAEMON, 0, 0, 0, 0);
 
     /*
      * Mount the AFS filesystem
@@ -2007,8 +1996,9 @@ syscallThread(void *argp)
     return 0;
 }
 
-fork_syscall(syscall, afscall, param1, param2, param3, param4)
-     long syscall, afscall, param1, param2, param3, param4;
+int
+fork_syscall(long syscall, long afscall, long param1, long param2,
+	     long param3, long param4)
 {
     usr_thread_t tid;
     struct syscallThreadArgs *sysArgsP;
@@ -2028,8 +2018,9 @@ fork_syscall(syscall, afscall, param1, param2, param3, param4)
     return 0;
 }
 
-call_syscall(syscall, afscall, param1, param2, param3, param4)
-     long syscall, afscall, param1, param2, param3, param4;
+int
+call_syscall(long syscall, long afscall, long param1, long param2,
+	     long param3, long param4)
 {
     int code = 0;
     struct a {
@@ -2066,6 +2057,7 @@ uafs_SetTokens(char *tbuffer, int tlen)
     iob.in_size = tlen;
     iob.out = &outbuf[0];
     iob.out_size = sizeof(outbuf);
+
     rc = call_syscall(AFSCALL_PIOCTL, 0, _VICEIOCTL(3), (long)&iob, 0, 0);
     if (rc != 0) {
 	errno = rc;
@@ -2210,6 +2202,7 @@ uafs_LookupName(char *path, struct usr_vnode *parentVp,
     struct usr_vnode *vp;
     struct usr_vnode *nextVp;
     struct usr_vnode *linkVp;
+    struct vcache *nextVc;
     char *tmpPath;
     char *pathP;
     char *nextPathP = NULL;
@@ -2279,17 +2272,20 @@ uafs_LookupName(char *path, struct usr_vnode *parentVp,
 	     * lookup the next component in the path, we can release the
 	     * subdirectory since we hold the global lock
 	     */
+	    nextVc = NULL;
 	    nextVp = NULL;
 #ifdef AFS_WEB_ENHANCEMENTS
 	    if ((nextPathP != NULL && *nextPathP != '\0') || !no_eval_mtpt)
-		code = afs_lookup(vp, pathP, &nextVp, u.u_cred, 0);
+		code = afs_lookup(VTOAFS(vp), pathP, &nextVc, u.u_cred, 0);
 	    else
 		code =
-		    afs_lookup(vp, pathP, &nextVp, u.u_cred,
+		    afs_lookup(VTOAFS(vp), pathP, &nextVc, u.u_cred,
 			       AFS_LOOKUP_NOEVAL);
 #else
-	    code = afs_lookup(vp, pathP, &nextVp, u.u_cred, 0);
+	    code = afs_lookup(VTOAFS(vp), pathP, &nextVc, u.u_cred, 0);
 #endif /* AFS_WEB_ENHANCEMENTS */
+	    if (nextVc)
+		nextVp=AFSTOV(nextVc);
 	    if (code != 0) {
 		VN_RELE(vp);
 		afs_osi_Free(tmpPath, strlen(path) + 1);
@@ -2379,7 +2375,7 @@ uafs_LookupLink(struct usr_vnode *vp, struct usr_vnode *parentVp,
     /*
      * Read the link data
      */
-    code = afs_readlink(vp, &uio, u.u_cred);
+    code = afs_readlink(VTOAFS(vp), &uio, u.u_cred);
     if (code) {
 	afs_osi_Free(pathP, MAX_OSI_PATH + 1);
 	return code;
@@ -2542,7 +2538,7 @@ uafs_mkdir_r(char *path, int mode)
     int code;
     char *nameP;
     struct vnode *parentP;
-    struct vnode *dirP;
+    struct vcache *dirP;
     struct usr_vattr attrs;
 
     if (uafs_IsRoot(path)) {
@@ -2583,13 +2579,13 @@ uafs_mkdir_r(char *path, int mode)
     attrs.va_uid = u.u_cred->cr_uid;
     attrs.va_gid = u.u_cred->cr_gid;
     dirP = NULL;
-    code = afs_mkdir(parentP, nameP, &attrs, &dirP, u.u_cred);
+    code = afs_mkdir(VTOAFS(parentP), nameP, &attrs, &dirP, u.u_cred);
     VN_RELE(parentP);
     if (code != 0) {
 	errno = code;
 	return -1;
     }
-    VN_RELE(dirP);
+    VN_RELE(AFSTOV(dirP));
     return 0;
 }
 
@@ -3329,7 +3325,7 @@ uafs_fsync_r(int fd)
 	return -1;
     }
 
-    code = afs_fsync(fileP, u.u_cred);
+    code = afs_fsync(VTOAFS(fileP), u.u_cred);
     if (code != 0) {
 	errno = code;
 	return -1;
@@ -3364,7 +3360,7 @@ uafs_close_r(int fd)
     }
     afs_FileTable[fd] = NULL;
 
-    code = afs_close(fileP, afs_FileFlags[fd], u.u_cred);
+    code = afs_close(VTOAFS(fileP), afs_FileFlags[fd], u.u_cred);
     VN_RELE(fileP);
     if (code != 0) {
 	errno = code;
@@ -3439,7 +3435,7 @@ uafs_link_r(char *existing, char *new)
     /*
      * Create the link
      */
-    code = afs_link(existP, dirP, nameP, u.u_cred);
+    code = afs_link(VTOAFS(existP), VTOAFS(dirP), nameP, u.u_cred);
     VN_RELE(existP);
     VN_RELE(dirP);
     if (code != 0) {
@@ -3508,7 +3504,7 @@ uafs_symlink_r(char *target, char *source)
     attrs.va_mode = 0777;
     attrs.va_uid = u.u_cred->cr_uid;
     attrs.va_gid = u.u_cred->cr_gid;
-    code = afs_symlink(dirP, nameP, &attrs, target, u.u_cred);
+    code = afs_symlink(VTOAFS(dirP), nameP, &attrs, target, u.u_cred);
     VN_RELE(dirP);
     if (code != 0) {
 	errno = code;
@@ -3565,7 +3561,7 @@ uafs_readlink_r(char *path, char *buf, int len)
     /*
      * Read the the link
      */
-    code = afs_readlink(vp, &uio, u.u_cred);
+    code = afs_readlink(VTOAFS(vp), &uio, u.u_cred);
     VN_RELE(vp);
     if (code) {
 	errno = code;
@@ -3596,8 +3592,6 @@ int
 uafs_unlink_r(char *path)
 {
     int code;
-    int openFlags;
-    struct usr_vnode *fileP;
     struct usr_vnode *dirP;
     char *nameP;
 
@@ -3633,7 +3627,7 @@ uafs_unlink_r(char *path)
     /*
      * Remove the file
      */
-    code = afs_remove(dirP, nameP, u.u_cred);
+    code = afs_remove(VTOAFS(dirP), nameP, u.u_cred);
     VN_RELE(dirP);
     if (code != 0) {
 	errno = code;
@@ -3710,7 +3704,7 @@ uafs_rename_r(char *old, char *new)
     /*
      * Rename the file
      */
-    code = afs_rename(odirP, onameP, ndirP, nnameP, u.u_cred);
+    code = afs_rename(VTOAFS(odirP), onameP, VTOAFS(ndirP), nnameP, u.u_cred);
     VN_RELE(odirP);
     VN_RELE(ndirP);
     if (code != 0) {
@@ -3739,8 +3733,6 @@ int
 uafs_rmdir_r(char *path)
 {
     int code;
-    int openFlags;
-    struct usr_vnode *fileP;
     struct usr_vnode *dirP;
     char *nameP;
 
@@ -3776,7 +3768,7 @@ uafs_rmdir_r(char *path)
     /*
      * Remove the directory
      */
-    code = afs_rmdir(dirP, nameP, u.u_cred);
+    code = afs_rmdir(VTOAFS(dirP), nameP, u.u_cred);
     VN_RELE(dirP);
     if (code != 0) {
 	errno = code;
@@ -3924,7 +3916,7 @@ uafs_getdents_r(int fd, struct min_direct *buf, int len)
     /*
      * read the next chunk from the directory
      */
-    code = afs_readdir(vp, &uio, u.u_cred);
+    code = afs_readdir(VTOAFS(vp), &uio, u.u_cred);
     if (code != 0) {
 	errno = code;
 	return -1;
@@ -3950,7 +3942,6 @@ uafs_readdir(usr_DIR * dirp)
 struct usr_dirent *
 uafs_readdir_r(usr_DIR * dirp)
 {
-    int rc;
     int code;
     int len;
     struct usr_uio uio;
@@ -3989,7 +3980,7 @@ uafs_readdir_r(usr_DIR * dirp)
 	/*
 	 * read the next chunk from the directory
 	 */
-	code = afs_readdir(vp, &uio, u.u_cred);
+	code = afs_readdir(VTOAFS(vp), &uio, u.u_cred);
 	if (code != 0) {
 	    errno = code;
 	    return NULL;
@@ -4264,8 +4255,6 @@ int
 uafs_statmountpoint(char *path)
 {
     int retval;
-    int code;
-    char buf[256];
 
     AFS_GLOCK();
     retval = uafs_statmountpoint_r(path);
@@ -4279,7 +4268,6 @@ uafs_statmountpoint_r(char *path)
     int code;
     struct vnode *vp;
     struct vcache *avc;
-    struct vrequest treq;
     int r;
 
     code = uafs_LookupName(path, afs_CurrentDir, &vp, 0, 1);
@@ -4302,7 +4290,7 @@ uafs_statmountpoint_r(char *path)
 int
 uafs_getRights(char *path)
 {
-    int code, rc;
+    int code;
     struct vnode *vp;
     int afs_rights;
 
@@ -4318,7 +4306,7 @@ uafs_getRights(char *path)
 	PRSFS_READ | PRSFS_WRITE | PRSFS_INSERT | PRSFS_LOOKUP | PRSFS_DELETE
 	| PRSFS_LOCK | PRSFS_ADMINISTER;
 
-    afs_rights = afs_getRights(vp, afs_rights, u.u_cred);
+    afs_rights = afs_getRights(VTOAFS(vp), afs_rights, u.u_cred);
 
     AFS_GUNLOCK();
     return afs_rights;
