@@ -22,8 +22,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_access.c,v 1.11.8.10 2009/01/26 18:52:42 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -359,7 +357,7 @@ afs_getRights(OSI_VC_DECL(avc), register afs_int32 arights,
     struct vrequest treq;
     OSI_VC_CONVERT(avc);
 
-    if (code = afs_InitReq(&treq, acred))
+    if ((code = afs_InitReq(&treq, acred)))
 	return code;
 
     code = afs_VerifyVCache(avc, &treq);
