@@ -20,8 +20,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_remove.c,v 1.52.2.15 2009/03/18 13:41:37 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -436,7 +434,7 @@ afs_remove(OSI_VC_DECL(adp), char *aname, struct AFS_UCRED *acred)
 	if (!code) {
 	    struct VenusFid *oldmvid = NULL;
 	    if (tvc->mvid) 
-		oldmvid = (char *)tvc->mvid;
+		oldmvid = tvc->mvid;
 	    tvc->mvid = (struct VenusFid *)unlname;
 	    if (oldmvid)
 		osi_FreeSmallSpace(oldmvid);
