@@ -22,8 +22,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.29.4.8 2007/01/15 15:51:01 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -145,6 +143,7 @@ getpag(void)
  */
 
 static int afs_pag_sleepcnt = 0;
+static int afs_pag_timewarn = 0;
 
 static int
 afs_pag_sleep(struct AFS_UCRED **acred)
@@ -155,6 +154,13 @@ afs_pag_sleep(struct AFS_UCRED **acred)
 	if(osi_Time() - pag_epoch < pagCounter) {
 	    rv = 1;
 	}
+	if (rv && (osi_Time() < pag_epoch)) {
+	    if (!afs_pag_timewarn) {
+		afs_pag_timewarn = 1;
+		printf("clock went backwards, not PAG throttling");
+	    }
+	    rv = 0;
+	}
     }
 
     return rv;
@@ -248,13 +254,13 @@ afs_setpag(void)
     }
 #elif defined(AFS_DARWIN80_ENV)
     {
-	struct ucred *credp = kauth_cred_proc_ref(p);
+	struct AFS_UCRED *credp = kauth_cred_proc_ref(p);
 	code = AddPag(p, genpag(), &credp);
-	kauth_cred_rele(credp);
+	crfree(credp);
     }
 #elif defined(AFS_DARWIN_ENV)
     {
-	struct ucred *credp = crdup(p->p_cred->pc_ucred);
+	struct AFS_UCRED *credp = crdup(p->p_cred->pc_ucred);
 	code = AddPag(p, genpag(), &credp);
 	crfree(credp);
     }
@@ -370,7 +376,7 @@ afs_setpag_val(int pagval)
 
 #ifndef AFS_LINUX26_ONEGROUP_ENV
 int
-afs_getpag_val()
+afs_getpag_val(void)
 {
     int pagvalue;
     struct AFS_UCRED *credp = u.u_cred;
@@ -401,7 +407,8 @@ int
 AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
 #endif
 {
-    afs_int32 newpag, code;
+    afs_int32 code;
+    afs_uint32 newpag;
 
     AFS_STATCNT(AddPag);
 #if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
@@ -421,13 +428,22 @@ AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
 int
 afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred)
 {
+#if defined(AFS_LINUX26_ENV) && !defined(AFS_NONFSTRANS)
     int code;
+#endif
+    int i = 0;
 
     AFS_STATCNT(afs_InitReq);
     memset(av, 0, sizeof(*av));
     if (afs_shuttingdown)
 	return EIO;
 
+    av->idleError = 0;
+    av->tokenError = 0;
+    while (i < MAXHOSTS) {
+      av->skipserver[i] = 0;
+      i++;
+    }
 #ifdef AFS_LINUX26_ENV
 #if !defined(AFS_NONFSTRANS)
     if (osi_linux_nfs_initreq(av, acred, &code))
@@ -505,7 +521,9 @@ afs_get_pag_from_groups(gid_t g0a, gid_t g1a)
 void
 afs_get_groups_from_pag(afs_uint32 pag, gid_t * g0p, gid_t * g1p)
 {
+#ifndef AFS_LINUX26_ONEGROUP_ENV
     unsigned short g0, g1;
+#endif
 
 
     AFS_STATCNT(afs_get_groups_from_pag);
@@ -527,10 +545,12 @@ afs_get_groups_from_pag(afs_uint32 pag, gid_t * g0p, gid_t * g1p)
 
 
 afs_int32
-PagInCred(const struct AFS_UCRED *cred)
+PagInCred(struct AFS_UCRED *cred)
 {
     afs_int32 pag;
+#if !defined(AFS_LINUX26_ONEGROUP_ENV)
     gid_t g0, g1;
+#endif
 #if defined(AFS_SUN510_ENV)
     const gid_t *gids;
     int ngroups;
@@ -554,11 +574,7 @@ PagInCred(const struct AFS_UCRED *cred)
     g0 = cred->cr_groups[1];
     g1 = cred->cr_groups[2];
 #else
-#if defined(AFS_AIX51_ENV)
-    if (kcred_getpag(cred, PAG_AFS, &pag) < 0 || pag == 0)
-	pag = NOPAG;
-    return pag;
-#elif defined(AFS_AIX_ENV)
+#if defined(AFS_AIX_ENV)
     if (cred->cr_ngrps < 2) {
 	return NOPAG;
     }
@@ -597,19 +613,22 @@ PagInCred(const struct AFS_UCRED *cred)
 #else
     pag = (afs_int32) afs_get_pag_from_groups(g0, g1);
 #endif
+#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DUX40_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_XBSD_ENV)
 out:
+#endif
 #if defined(AFS_LINUX26_ENV) && defined(LINUX_KEYRING_SUPPORT)
-    if (pag == NOPAG) {
+    if (pag == NOPAG && cred->cr_rgid != NFSXLATOR_CRED) {
 	struct key *key;
-	afs_uint32 pag, newpag;
+	afs_uint32 upag, newpag;
 
 	key = request_key(&key_type_afs_pag, "_pag", NULL);
 	if (!IS_ERR(key)) {
 	    if (key_validate(key) == 0 && key->uid == 0) {	/* also verify in the session keyring? */
-
-		pag = (afs_uint32) key->payload.value;
-		if (((pag >> 24) & 0xff) == 'A')
-		    __setpag(&cred, pag, &newpag, 0);
+		upag = (afs_uint32) key->payload.value;
+		if (((upag >> 24) & 0xff) == 'A') {
+		    __setpag(&cred, upag, &newpag, 0);
+		    pag = (afs_int32) upag;
+		}
 	    }
 	    key_put(key);
 	} 
