@@ -10,13 +10,12 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_pag_call.c,v 1.1.2.3 2008/07/01 03:35:23 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"
 #include "rx/rx_globals.h"
+#include "rx/rxstat.h"
 #if !defined(UKERNEL) && !defined(AFS_LINUX20_ENV)
 #include "net/if.h"
 #ifdef AFS_SGI62_ENV
@@ -103,10 +102,10 @@ void afspag_Init(afs_int32 nfs_server_addr)
     rx_Init(htons(7001));
 
     AFS_STATCNT(afs_ResourceInit);
-    RWLOCK_INIT(&afs_xuser, "afs_xuser");
-    RWLOCK_INIT(&afs_xpagcell, "afs_xpagcell");
-    RWLOCK_INIT(&afs_xpagsys, "afs_xpagsys");
-    RWLOCK_INIT(&afs_icl_lock, "afs_icl_lock");
+    AFS_RWLOCK_INIT(&afs_xuser, "afs_xuser");
+    AFS_RWLOCK_INIT(&afs_xpagcell, "afs_xpagcell");
+    AFS_RWLOCK_INIT(&afs_xpagsys, "afs_xpagsys");
+    AFS_RWLOCK_INIT(&afs_icl_lock, "afs_icl_lock");
 #ifndef AFS_FBSD_ENV
     LOCK_INIT(&osi_fsplock, "osi_fsplock");
     LOCK_INIT(&osi_flplock, "osi_flplock");
@@ -135,7 +134,7 @@ void afspag_Init(afs_int32 nfs_server_addr)
 #ifdef RXK_LISTENER_ENV
     afs_start_thread(rxk_Listener,       "Rx Listener");
 #endif
-    afs_start_thread(rx_ServerProc,      "Rx Server Thread");
+    afs_start_thread((void *)(void *)rx_ServerProc,      "Rx Server Thread");
     afs_start_thread(afs_rxevent_daemon, "Rx Event Daemon");
     afs_start_thread(afs_Daemon,         "AFS PAG Daemon");
 
