@@ -26,7 +26,6 @@ extern void afs_FreeAllAxs(struct axscache **headp);
 /* afs_buffer.c */
 extern void DInit(int abuffers);
 extern void *DRead(register struct dcache * fid, register int page);
-extern void DRelease(register struct buffer *bp, int flag);
 extern int DVOffset(register void *ap);
 extern void DZap(struct dcache * fid);
 extern void DFlush(void);
@@ -46,6 +45,11 @@ extern void shutdown_afstest(void);
 extern void afs_shutdown_BKG(void);
 extern int afs_syscall_call(long parm, long parm2, long parm3,
 			    long parm4, long parm5, long parm6);
+#if defined(AFS_DARWIN100_ENV)
+extern int afs_syscall64_call(user_addr_t parm, user_addr_t parm2,
+			      user_addr_t parm3, user_addr_t parm4,
+			      user_addr_t parm5, user_addr_t parm6);
+#endif
 
 
 /* afs_callback.c */
@@ -130,11 +134,7 @@ extern struct afs_q CellLRU;
 
 extern void afs_CellInit(void);
 extern void shutdown_cell(void);
-#if defined(LINUX_USE_FH)
-extern int afs_cellname_init(struct fid *fh, int fh_type, int lookupcode);
-#else
-extern int afs_cellname_init(ino_t inode, int lookupcode);
-#endif
+extern int afs_cellname_init(afs_dcache_id_t *inode, int lookupcode);
 extern int afs_cellname_write(void);
 extern afs_int32 afs_NewCell(char *acellName, afs_int32 * acellHosts,
 			     int aflags, char *linkedcname, u_short fsport,
@@ -213,6 +213,7 @@ extern struct brequest *afs_BQueue(register short aopcode,
 				   struct AFS_UCRED *acred,
 				   afs_size_t asparm0, afs_size_t asparm1,
 				   void *apparm0);
+extern void afs_SetCheckServerNATmode(int isnat);
 extern void afs_CheckServerDaemon(void);
 extern int afs_CheckRootVolume(void);
 extern void afs_BRelease(register struct brequest *ab);
@@ -236,12 +237,7 @@ extern int cacheDiskType;
 extern afs_uint32 afs_tpct1, afs_tpct2, splitdcache;
 extern unsigned char *afs_indexFlags;
 extern struct afs_cacheOps *afs_cacheType;
-#if defined(LINUX_USE_FH)
-extern struct fid cacheitems_fh;
-extern int cacheitems_fh_type;
-#else
-extern ino_t cacheInode;
-#endif
+extern afs_dcache_id_t cacheInode;
 extern struct osi_file *afs_cacheInodep;
 extern void afs_dcacheInit(int afiles, int ablocks, int aDentries, int achunk,
 			   int aflags);
@@ -328,6 +324,17 @@ extern struct afs_exporter *root_exported;
 extern struct afs_exporter *exporter_find(int type);
 extern void shutdown_exporter(void);
 
+/* afs_fetchstore.c */
+extern int afs_UFSCacheFetchProc(struct rx_call *, struct osi_file *,
+                                 afs_size_t, struct dcache *,
+                                 struct vcache *, afs_size_t *,
+                                 afs_size_t *, afs_int32);
+
+extern int afs_UFSCacheStoreProc(struct rx_call *, struct osi_file *,
+                                 afs_int32, struct vcache *,
+                                 int *, afs_size_t *,
+                                 afs_size_t *);
+
 /* afs_icl.c */
 extern struct afs_icl_set *afs_icl_allSets;
 extern int afs_icl_InitLogs(void);
@@ -403,7 +410,10 @@ extern void afs_icl_AppendRecord(register struct afs_icl_log *logp,
 				 long p2, long p3, long p4);
 extern int Afscall_icl(long opcode, long p1, long p2, long p3, long p4,
 		       long *retval);
-
+#ifdef AFS_DARWIN100_ENV
+extern int Afscall64_icl(int opcode, user_addr_t p1, user_addr_t p2,
+		       user_addr_t p3, user_addr_t p4, int *retval);
+#endif
 
 /* afs_init.c */
 extern struct cm_initparams cm_initParams;
@@ -427,6 +437,8 @@ extern int afs_ResourceInit(int preallocs);
 extern void shutdown_cache(void);
 extern void shutdown_vnodeops(void);
 extern void shutdown_AFS(void);
+extern int afs_LookupInodeByPath(char *filename, afs_ufs_dcache_id_t *inode,
+				 struct vnode **fvpp);
 
 /* afs_lock.c */
 extern void Lock_Init(register struct afs_lock *lock);
@@ -474,35 +486,34 @@ extern void shutdown_mariner(void);
 /* afs_memcache.c */
 extern int afs_InitMemCache(int blkCount, int blkSize, int flags);
 extern int afs_MemCacheClose(struct osi_file *file);
-#if defined(AFS_SUN57_64BIT_ENV) || defined(AFS_SGI62_ENV)
-extern void *afs_MemCacheOpen(ino_t blkno);
-#else
-extern void *afs_MemCacheOpen(afs_int32 blkno);
-#endif
+extern void *afs_MemCacheOpen(afs_dcache_id_t *ainode);
 extern int afs_MemReadBlk(register struct osi_file *fP, int offset,
 			  void *dest, int size);
 extern int afs_MemReadvBlk(register struct memCacheEntry *mceP, int offset,
 			   struct iovec *iov, int nio, int size);
-extern int afs_MemReadUIO(ino_t blkno, struct uio *uioP);
+extern int afs_MemReadUIO(afs_dcache_id_t *ainode, struct uio *uioP);
 extern int afs_MemWriteBlk(register struct osi_file *fP, int offset,
 			   void *src, int size);
 extern int afs_MemWritevBlk(register struct memCacheEntry *mceP, int offset,
 			    struct iovec *iov, int nio, int size);
-extern int afs_MemWriteUIO(ino_t blkno, struct uio *uioP);
+extern int afs_MemWriteUIO(afs_dcache_id_t *ainode, struct uio *uioP);
 extern int afs_MemCacheTruncate(register struct osi_file *fP,
 				int size);
-extern int afs_MemCacheStoreProc(register struct rx_call *acall,
-				 register struct osi_file *fP,
-				 register afs_int32 alen, struct vcache *avc,
-				 int *shouldWake, afs_size_t * abytesToXferP,
-				 afs_size_t * abytesXferredP);
-extern int afs_MemCacheFetchProc(register struct rx_call *acall,
-				 register struct osi_file *fP,
-				 afs_size_t abase, struct dcache *adc,
-				 struct vcache *avc,
-				 afs_size_t * abytesToXferP,
-				 afs_size_t * abytesXferredP,
-				 afs_int32 lengthFound);
+extern int afs_CacheStoreVCache(struct dcache **dcList,
+				struct vcache *avc,
+				struct vrequest *areq,
+				int sync,
+				unsigned int minj,
+				unsigned int high,
+				unsigned int moredata,
+				afs_hyper_t *anewDV,
+                                 afs_size_t *amaxStoredLength);
+extern int afs_CacheFetchProc(register struct afs_conn *tc,
+				register struct osi_file *fP,
+				afs_size_t abase, struct dcache *adc,
+				struct vcache *avc,
+				afs_int32 size,
+				struct afs_FetchOutput *tsmall);
 extern void shutdown_memcache(void);
 
 
@@ -575,7 +586,7 @@ extern int AddPag(struct proc *p, afs_int32 aval, struct AFS_UCRED **credpp);
 extern int AddPag(afs_int32 aval, struct AFS_UCRED **credpp);
 #endif
 extern int afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred);
-#if defined(UKERNEL) && defined(AFS_WEB_ENHANCEMENTS)
+#if defined(UKERNEL)
 extern afs_uint32 afs_get_pag_from_groups(gid_t g0a, gid_t g1a);
 #else
 #ifdef AFS_LINUX26_ONEGROUP_ENV
@@ -665,15 +676,9 @@ extern int afs_syscall_iincdec(int, int, int, int);
 
 /* ARCH/osi_file.c */
 extern int afs_osicred_initialized;
-#if defined(AFS_SUN57_64BIT_ENV) || defined(AFS_SGI62_ENV)
-extern void *osi_UFSOpen(ino_t ainode);
-#else
-#if defined(LINUX_USE_FH)
-extern void *osi_UFSOpen_fh(struct fid *fh, int fh_type);
-extern int osi_get_fh(struct dentry *dp, struct fid *fh, int *max_len);
-#else
-extern void *osi_UFSOpen(afs_int32 ainode);
-#endif
+extern void *osi_UFSOpen(afs_dcache_id_t *ainode);
+#if defined(AFS_LINUX22_ENV)
+extern void osi_get_fh(struct dentry *dp, afs_ufs_dcache_id_t *ainode);
 #endif
 extern int afs_osi_Stat(register struct osi_file *afile,
 			register struct osi_stat *astat);
@@ -690,9 +695,16 @@ extern void shutdown_osifile(void);
 
 
 /* ARCH/osi_groups.c */
-#ifdef AFS_XBSD_ENV
+#if defined(UKERNEL)
+extern int usr_setpag(struct usr_ucred **cred, afs_uint32 pagvalue,
+		      afs_uint32 * newpag, int change_parent);
+#else
+# if defined AFS_XBSD_ENV
+#  if !defined(AFS_DFBSD_ENV)
 extern int setpag(struct proc *proc, struct ucred **cred, afs_uint32 pagvalue,
 		  afs_uint32 * newpag, int change_parent);
+#  endif
+# endif
 #endif
 
 
@@ -748,6 +760,12 @@ extern void vcache2inode(struct vcache *avc);
 extern void vcache2fakeinode(struct vcache *rootvp, struct vcache *mpvp);
 #endif
 
+#ifdef UKERNEL
+extern int afs_mount(struct vfs *afsp, char *path, void *data);
+extern int afs_root(OSI_VFS_DECL(afsp), struct vnode **avpp);
+extern int afs_unmount(struct vfs *afsp);
+#endif
+
 /* afs_pag_call.c */
 extern afs_int32 afs_nfs_server_addr;
 extern void afspag_Init(afs_int32 nfs_server_addr);
@@ -769,6 +787,11 @@ extern afs_int32 afs_waitForever;
 extern short afs_waitForeverCount;
 extern afs_int32 afs_showflags;
 extern int afs_defaultAsynchrony;
+#if defined(AFS_DARWIN100_ENV)
+extern int afs_syscall64_pioctl(user_addr_t path, unsigned int com,
+				user_addr_t cmarg, int follow, \
+				struct AFS_UCRED *credp);
+#endif
 #ifdef AFS_SUN5_ENV
 extern int afs_syscall_pioctl(char *path, unsigned int com, caddr_t cmarg, 
 			      int follow, rval_t *rvp, struct AFS_UCRED *credp);
@@ -863,8 +886,14 @@ extern void afs_AddToMean(struct afs_MeanStats *oldMean, afs_int32 newValue);
 #endif
 
 /* afs_syscall.c */
+#ifdef AFS_DARWIN100_ENV
+extern int copyin_afs_ioctl(user_addr_t cmarg, struct afs_ioctl *dst);
+#else
 extern int copyin_afs_ioctl(caddr_t cmarg, struct afs_ioctl *dst);
-
+#endif
+#ifdef UKERNEL
+extern int Afs_syscall(void);
+#endif
 
 /* UKERNEL/afs_usrops.c */
 #ifdef UKERNEL
@@ -872,11 +901,16 @@ extern void uafs_Shutdown(void);
 extern void osi_ReleaseVM(struct vcache *avc, int len,
 			  struct usr_ucred *credp);
 extern int osi_GetTime(struct timeval *tv);
+extern int iodone(struct usr_buf *bp);
+extern int usr_ioctl(void);
+extern int lookupname(char *fnamep, int segflg, int followlink,
+		      struct usr_vnode **compvpp);
+extern int usr_uiomove(char *kbuf, int n, int rw, struct usr_uio *uio);
+extern int afs_osi_VOP_RDWR(struct usr_vnode *vnodeP, struct usr_uio *uioP,
+		            int rw, int flags, struct usr_ucred *credP);
+
 #endif
 
-
-
-
 /* afs_user.c */
 extern afs_rwlock_t afs_xuser;
 extern struct unixuser *afs_users[NUSERS];
@@ -922,22 +956,21 @@ extern void print_internet_address(char *preamble, struct srvAddr *sa,
 				   char *postamble, int flag);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
 
-#if 0				/* problems - need to change to varargs, right now is incorrect usage
-				 * throughout code */
-extern void afs_warn(char *a, long b, long c, long d, long e, long f, long g,
-		     long h, long i, long j);
-extern void afs_warnuser(char *a, long b, long c, long d, long e, long f,
-			 long g, long h, long i, long j);
-#else
-extern void afs_warn();
-extern void afs_warnuser();
-#endif
 extern void afs_CheckLocks(void);
 extern int afs_badop(void);
 extern int afs_noop(void);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
 
+/* afs_warn.c */
 
+#ifdef AFS_AIX_ENV
+/* AIX doesn't have usable va_args support in its kernel */
+extern void afs_warn();
+extern void afs_warnuser();
+#else
+extern void afs_warn(char *fmt, ...);
+extern void afs_warnuser(char *fmt, ...);
+#endif
 
 /* afs_vcache.c */
 extern int afs_ShakeLooseVCaches(afs_int32 anumber);
@@ -1273,12 +1306,7 @@ extern afs_int32 afs_FVIndex;
 extern afs_int32 afs_volCounter;
 extern afs_rwlock_t afs_xvolume;
 extern struct volume *afs_volumes[NVOLS];
-#if defined(LINUX_USE_FH)
-extern struct fid volumeinfo_fh;
-extern int volumeinfo_fh_type;
-#else
-extern ino_t volumeInode;
-#endif
+extern afs_dcache_id_t volumeInode;
 extern struct volume *afs_FindVolume(struct VenusFid *afid,
 				     afs_int32 locktype);
 extern struct volume *afs_freeVolList;
@@ -1314,15 +1342,6 @@ extern void afs_ntohuuid(afsUUID * uuidp);
 extern afs_int32 afs_uuid_create(afsUUID * uuid);
 extern u_short afs_uuid_hash(afsUUID * uuid);
 
-
-/* MISC PROTOTYPES - THESE SHOULD NOT BE HERE */
-/* MOVE THEM TO APPROPRIATE LOCATIONS */
-extern afs_int32 RXAFSCB_ExecuteRequest(struct rx_call *acall);
-extern afs_int32 RXSTATS_ExecuteRequest(struct rx_call *acall);
-extern afs_int32 PAGCB_ExecuteRequest(struct rx_call *acall);
-
-
-
 #if defined(AFS_SUN5_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_AIX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SGI62_ENV) || defined(AFS_OSF_ENV)
 #include "osi_prototypes.h"
 #endif
