@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/auth/ktc_nt.c,v 1.16 2004/04/04 02:35:47 jaltman Exp $");
 
 #include <afs/stds.h>
 #include <stdio.h>
@@ -49,7 +47,7 @@ static char AFSConfigKeyName[] =
     "SYSTEM\\CurrentControlSet\\Services\\TransarcAFSDaemon\\Parameters";
 
 static char AFSGlobalKTCMutexName[] = "Global\\AFS_KTC_Mutex";
-static char AFSKTCMutexName[]       = "AFS_KTC_Mutex";
+static char AFSKTCMutexName[] = "AFS_KTC_Mutex";
 
 /*
  * Support for RPC's to send and receive session keys
@@ -113,12 +111,12 @@ send_key(afs_uuid_t uuid, char sessionKey[8])
 
     /* Encryption on by default */
     if (GetEnvironmentVariable("AFS_RPC_ENCRYPT", encrypt, sizeof(encrypt)))
-	if (!strcmpi(encrypt, "OFF"))
+	if (!_stricmp(encrypt, "OFF"))
 	    encryptionOff = TRUE;
 
-    /* Protocol sequence is named pipe by default */
+    /* Protocol sequence is local by default */
     if (!GetEnvironmentVariable("AFS_RPC_PROTSEQ", protseq, sizeof(protseq)))
-	strcpy(protseq, "ncacn_np");
+	strcpy(protseq, "ncalrpc");
 
     /* Server name */
     getservername(&serverNamep, sizeof(serverName));
@@ -186,12 +184,12 @@ receive_key(afs_uuid_t uuid, char sessionKey[8])
 
     /* Encryption on by default */
     if (GetEnvironmentVariable("AFS_RPC_ENCRYPT", encrypt, sizeof(encrypt)))
-	if (!strcmpi(encrypt, "OFF"))
+	if (!_stricmp(encrypt, "OFF"))
 	    encryptionOff = TRUE;
 
-    /* Protocol sequence is named pipe by default */
+    /* Protocol sequence is local by default */
     if (!GetEnvironmentVariable("AFS_RPC_PROTSEQ", protseq, sizeof(protseq)))
-	strcpy(protseq, "ncacn_np");
+	strcpy(protseq, "ncalrpc");
 
     /* Server name */
     getservername(&serverNamep, sizeof(serverName));
@@ -271,7 +269,7 @@ ktc_SetToken(struct ktc_principal *server, struct ktc_token *token,
 
     /* ticket length */
     memcpy(tp, &token->ticketLen, sizeof(token->ticketLen));
-    tp += sizeof(&token->ticketLen);
+    tp += sizeof(token->ticketLen);
 
     /* ticket */
     memcpy(tp, token->ticket, token->ticketLen);
@@ -317,14 +315,14 @@ ktc_SetToken(struct ktc_principal *server, struct ktc_token *token,
     tp += sizeof(temp);
 
     /* cell name */
-    temp = strlen(server->cell);
+    temp = (int)strlen(server->cell);
     if (temp >= MAXKTCREALMLEN)
 	return KTC_INVAL;
     strcpy(tp, server->cell);
     tp += temp + 1;
 
     /* user name */
-    temp = strlen(client->name);
+    temp = (int)strlen(client->name);
     if (temp >= MAXKTCNAMELEN)
 	return KTC_INVAL;
     strcpy(tp, client->name);
@@ -336,7 +334,7 @@ ktc_SetToken(struct ktc_principal *server, struct ktc_token *token,
 	if (client->smbname == NULL)
 	    temp = 0;
 	else
-	    temp = strlen(client->smbname);
+	    temp = (int)strlen(client->smbname);
 	if (temp == 0 || temp >= MAXKTCNAMELEN)
 	    return KTC_INVAL;
 	strcpy(tp, client->smbname);
@@ -351,41 +349,38 @@ ktc_SetToken(struct ktc_principal *server, struct ktc_token *token,
 
 #ifndef AFS_WIN95_ENV
     ktcMutex = CreateMutex(NULL, TRUE, AFSGlobalKTCMutexName);
-    if ( ktcMutex == NULL )
-        return KTC_PIOCTLFAIL;
-    if ( GetLastError() == ERROR_ALREADY_EXISTS ) {
-        if ( WaitForSingleObject( ktcMutex, INFINITE) != WAIT_OBJECT_0 ) {
-            CloseHandle(ktcMutex);
-            return KTC_PIOCTLFAIL;
-        }
+    if (ktcMutex == NULL)
+	return KTC_PIOCTLFAIL;
+    if (GetLastError() == ERROR_ALREADY_EXISTS) {
+	if (WaitForSingleObject(ktcMutex, INFINITE) != WAIT_OBJECT_0) {
+	    CloseHandle(ktcMutex);
+	    return KTC_PIOCTLFAIL;
+	}
     }
 
     /* RPC to send session key */
     status = send_key(uuid, token->sessionKey.data);
     if (status != RPC_S_OK) {
-        if (status == 1)
-            strcpy(rpcErr, "RPC failure in AFS gateway");
-        else
-            DceErrorInqText(status, rpcErr);
-        if (status == RPC_S_SERVER_UNAVAILABLE ||
-            status == EPT_S_NOT_REGISTERED) 
-        {
-            ReleaseMutex(ktcMutex);
-            CloseHandle(ktcMutex);
-            return KTC_NOCMRPC;
-        }
-        else 
-        {
-            ReleaseMutex(ktcMutex);
-            CloseHandle(ktcMutex);
-            return KTC_RPC;
-        }
+	if (status == 1)
+	    strcpy(rpcErr, "RPC failure in AFS gateway");
+	else
+	    DceErrorInqText(status, rpcErr);
+	if (status == RPC_S_SERVER_UNAVAILABLE ||
+	    status == EPT_S_NOT_REGISTERED) {
+	    ReleaseMutex(ktcMutex);
+	    CloseHandle(ktcMutex);
+	    return KTC_NOCMRPC;
+	} else {
+	    ReleaseMutex(ktcMutex);
+	    CloseHandle(ktcMutex);
+	    return KTC_RPC;
+	}
     }
 #endif /* AFS_WIN95_ENV */
 
     /* set up for pioctl */
     iob.in = tbuffer;
-    iob.in_size = tp - tbuffer;
+    iob.in_size = (long)(tp - tbuffer);
     iob.out = tbuffer;
     iob.out_size = sizeof(tbuffer);
 
@@ -397,17 +392,17 @@ ktc_SetToken(struct ktc_principal *server, struct ktc_token *token,
 #endif /* AFS_WIN95_ENV */
 
     if (code) {
-        if (code == -1) {
-            if (errno == ESRCH)
-                return KTC_NOCELL;
-            else if (errno == ENODEV)
-                return KTC_NOCM;
-            else if (errno == EINVAL)
-                return KTC_INVAL;
-            else
-                return KTC_PIOCTLFAIL;
-        } else
-            return KTC_PIOCTLFAIL;
+	if (code == -1) {
+	    if (errno == ESRCH)
+		return KTC_NOCELL;
+	    else if (errno == ENODEV)
+		return KTC_NOCM;
+	    else if (errno == EINVAL)
+		return KTC_INVAL;
+	    else
+		return KTC_PIOCTLFAIL;
+	} else
+	    return KTC_PIOCTLFAIL;
     }
 
     return 0;
@@ -450,44 +445,43 @@ ktc_GetToken(struct ktc_principal *server, struct ktc_token *token,
     tp += sizeof(uuid);
 
     iob.in = tbuffer;
-    iob.in_size = tp - tbuffer;
+    iob.in_size = (long)(tp - tbuffer);
     iob.out = tbuffer;
     iob.out_size = sizeof(tbuffer);
 
-#ifndef AFS_WIN95_ENV		
+#ifndef AFS_WIN95_ENV
     ktcMutex = CreateMutex(NULL, TRUE, AFSGlobalKTCMutexName);
-    if ( ktcMutex == NULL )
-        return KTC_PIOCTLFAIL;
-    if ( GetLastError() == ERROR_ALREADY_EXISTS ) {
-        if ( WaitForSingleObject( ktcMutex, INFINITE) != WAIT_OBJECT_0 ) {
-            CloseHandle(ktcMutex);
-            return KTC_PIOCTLFAIL;
-        }
+    if (ktcMutex == NULL)
+	return KTC_PIOCTLFAIL;
+    if (GetLastError() == ERROR_ALREADY_EXISTS) {
+	if (WaitForSingleObject(ktcMutex, INFINITE) != WAIT_OBJECT_0) {
+	    CloseHandle(ktcMutex);
+	    return KTC_PIOCTLFAIL;
+	}
     }
 #endif /* AFS_WIN95_ENV */
 
     code = pioctl(0, VIOCNEWGETTOK, &iob, 0);
     if (code) {
 #ifndef AFS_WIN95_ENV
-        ReleaseMutex(ktcMutex);
-        CloseHandle(ktcMutex);
+	ReleaseMutex(ktcMutex);
+	CloseHandle(ktcMutex);
 #endif /* AFS_WIN95_ENV */
-        if (code == -1) {
-            if (errno == ESRCH)
-                return KTC_NOCELL;
-            else if (errno == ENODEV)
-                return KTC_NOCM;
-            else if (errno == EINVAL)
-                return KTC_INVAL;
-            else if (errno == EDOM)
-                return KTC_NOENT;
-            else
-                return KTC_PIOCTLFAIL;
-        } else
-            return KTC_PIOCTLFAIL;
-    }                                                             
-
-#ifndef AFS_WIN95_ENV		
+	if (code == -1) {
+	    if (errno == ESRCH)
+		return KTC_NOCELL;
+	    else if (errno == ENODEV)
+		return KTC_NOCM;
+	    else if (errno == EINVAL)
+		return KTC_INVAL;
+	    else if (errno == EDOM)
+		return KTC_NOENT;
+	    else
+		return KTC_PIOCTLFAIL;
+	} else
+	    return KTC_PIOCTLFAIL;
+    }
+#ifndef AFS_WIN95_ENV
     /* get rid of RPC for win95 build */
     /* RPC to receive session key */
     status = receive_key(uuid, token->sessionKey.data);
@@ -496,15 +490,15 @@ ktc_GetToken(struct ktc_principal *server, struct ktc_token *token,
     CloseHandle(ktcMutex);
 
     if (status != RPC_S_OK) {
-        if (status == 1)
-            strcpy(rpcErr, "RPC failure in AFS gateway");
-        else
-            DceErrorInqText(status, rpcErr);
-        if (status == RPC_S_SERVER_UNAVAILABLE
-             || status == EPT_S_NOT_REGISTERED)
-            return KTC_NOCMRPC;
-        else 
-            return KTC_RPC;
+	if (status == 1)
+	    strcpy(rpcErr, "RPC failure in AFS gateway");
+	else
+	    DceErrorInqText(status, rpcErr);
+	if (status == RPC_S_SERVER_UNAVAILABLE
+	    || status == EPT_S_NOT_REGISTERED)
+	    return KTC_NOCMRPC;
+	else
+	    return KTC_RPC;
     }
 #endif /* AFS_WIN95_ENV */
 
@@ -533,18 +527,18 @@ ktc_GetToken(struct ktc_principal *server, struct ktc_token *token,
 
     /* remember cell name and skip over it */
     cellName = cp;
-    cellNameSize = strlen(cp);
+    cellNameSize = (int)strlen(cp);
     cp += cellNameSize + 1;
 
     /* user name is here */
 
     /* check that ticket will fit 
-	 * this compares the size of the ktc_token allocated by the app
-	 * which might be smaller than the current definition of MAXKTCTICKETLEN
-	 */
-	maxLen = tokenLen - sizeof(struct ktc_token) + MAXKTCTICKETLEN;
-	if (maxLen < ticketLen)
-		return KTC_TOOBIG;
+     * this compares the size of the ktc_token allocated by the app
+     * which might be smaller than the current definition of MAXKTCTICKETLEN
+     */
+    maxLen = tokenLen - sizeof(struct ktc_token) + MAXKTCTICKETLEN;
+    if (maxLen < ticketLen)
+	return KTC_TOOBIG;
 
     /* set return values */
     memcpy(token->ticket, ticketP, ticketLen);
@@ -580,15 +574,15 @@ ktc_ListTokens(int cellNum, int *cellNumP, struct ktc_principal *server)
     int code;
     HANDLE ktcMutex = NULL;
 
-#ifndef AFS_WIN95_ENV		
+#ifndef AFS_WIN95_ENV
     ktcMutex = CreateMutex(NULL, TRUE, AFSGlobalKTCMutexName);
-    if ( ktcMutex == NULL )
-        return KTC_PIOCTLFAIL;
-    if ( GetLastError() == ERROR_ALREADY_EXISTS ) {
-        if ( WaitForSingleObject( ktcMutex, INFINITE) != WAIT_OBJECT_0 ) {
-            CloseHandle(ktcMutex);
-            return KTC_PIOCTLFAIL;
-        }
+    if (ktcMutex == NULL)
+	return KTC_PIOCTLFAIL;
+    if (GetLastError() == ERROR_ALREADY_EXISTS) {
+	if (WaitForSingleObject(ktcMutex, INFINITE) != WAIT_OBJECT_0) {
+	    CloseHandle(ktcMutex);
+	    return KTC_PIOCTLFAIL;
+	}
     }
 #endif /* AFS_WIN95_ENV */
 
@@ -600,15 +594,15 @@ ktc_ListTokens(int cellNum, int *cellNumP, struct ktc_principal *server)
 
     /* do pioctl */
     iob.in = tbuffer;
-    iob.in_size = tp - tbuffer;
+    iob.in_size = (long)(tp - tbuffer);
     iob.out = tbuffer;
     iob.out_size = sizeof(tbuffer);
 
     code = pioctl(0, VIOCGETTOK, &iob, 0);
 
 #ifndef AFS_WIN95_ENV
-        ReleaseMutex(ktcMutex);
-        CloseHandle(ktcMutex);
+    ReleaseMutex(ktcMutex);
+    CloseHandle(ktcMutex);
 #endif /* AFS_WIN95_ENV */
 
     if (code) {
@@ -675,16 +669,15 @@ ktc_ForgetToken(struct ktc_principal *server)
     if (strcmp(server->name, "afs")) {
 	return ForgetOneLocalToken(server);
     }
-
-#ifndef AFS_WIN95_ENV		
+#ifndef AFS_WIN95_ENV
     ktcMutex = CreateMutex(NULL, TRUE, AFSGlobalKTCMutexName);
-    if ( ktcMutex == NULL )
-        return KTC_PIOCTLFAIL;
-    if ( GetLastError() == ERROR_ALREADY_EXISTS ) {
-        if ( WaitForSingleObject( ktcMutex, INFINITE) != WAIT_OBJECT_0 ) {
-            CloseHandle(ktcMutex);
-            return KTC_PIOCTLFAIL;
-        }
+    if (ktcMutex == NULL)
+	return KTC_PIOCTLFAIL;
+    if (GetLastError() == ERROR_ALREADY_EXISTS) {
+	if (WaitForSingleObject(ktcMutex, INFINITE) != WAIT_OBJECT_0) {
+	    CloseHandle(ktcMutex);
+	    return KTC_PIOCTLFAIL;
+	}
     }
 #endif /* AFS_WIN95_ENV */
 
@@ -696,7 +689,7 @@ ktc_ForgetToken(struct ktc_principal *server)
 
     /* do pioctl */
     iob.in = tbuffer;
-    iob.in_size = tp - tbuffer;
+    iob.in_size = (long)(tp - tbuffer);
     iob.out = tbuffer;
     iob.out_size = sizeof(tbuffer);
 
@@ -731,15 +724,15 @@ ktc_ForgetAllTokens()
 
     (void)ForgetLocalTokens();
 
-#ifndef AFS_WIN95_ENV		
+#ifndef AFS_WIN95_ENV
     ktcMutex = CreateMutex(NULL, TRUE, AFSGlobalKTCMutexName);
-    if ( ktcMutex == NULL )
-        return KTC_PIOCTLFAIL;
-    if ( GetLastError() == ERROR_ALREADY_EXISTS ) {
-        if ( WaitForSingleObject( ktcMutex, INFINITE) != WAIT_OBJECT_0 ) {
-            CloseHandle(ktcMutex);
-            return KTC_PIOCTLFAIL;
-        }
+    if (ktcMutex == NULL)
+	return KTC_PIOCTLFAIL;
+    if (GetLastError() == ERROR_ALREADY_EXISTS) {
+	if (WaitForSingleObject(ktcMutex, INFINITE) != WAIT_OBJECT_0) {
+	    CloseHandle(ktcMutex);
+	    return KTC_PIOCTLFAIL;
+	}
     }
 #endif /* AFS_WIN95_ENV */
 
@@ -790,7 +783,8 @@ SetLocalToken(struct ktc_principal *aserver, struct ktc_token *atoken,
     int found = -1;
     int i;
 
-    LOCK_GLOBAL_MUTEX for (i = 0; i < MAXLOCALTOKENS; i++)
+    LOCK_GLOBAL_MUTEX;
+    for (i = 0; i < MAXLOCALTOKENS; i++)
 	if (local_tokens[i].valid) {
 	    if ((strcmp(local_tokens[i].server.name, aserver->name) == 0)
 		&& (strcmp(local_tokens[i].server.instance, aserver->instance)
@@ -802,7 +796,8 @@ SetLocalToken(struct ktc_principal *aserver, struct ktc_token *atoken,
 	} else if (found == -1)
 	    found = i;		/* remember empty slot but keep looking for a match */
     if (found == -1) {
-	UNLOCK_GLOBAL_MUTEX return KTC_NOENT;
+	UNLOCK_GLOBAL_MUTEX;
+	return KTC_NOENT;
     }
     memcpy(&local_tokens[found].token, atoken, sizeof(struct ktc_token));
     memcpy(&local_tokens[found].server, aserver,
@@ -810,7 +805,8 @@ SetLocalToken(struct ktc_principal *aserver, struct ktc_token *atoken,
     memcpy(&local_tokens[found].client, aclient,
 	   sizeof(struct ktc_principal));
     local_tokens[found].valid = 1;
-    UNLOCK_GLOBAL_MUTEX return 0;
+    UNLOCK_GLOBAL_MUTEX;
+    return 0;
 }
 
 
@@ -820,7 +816,8 @@ GetLocalToken(struct ktc_principal *aserver, struct ktc_token *atoken,
 {
     int i;
 
-    LOCK_GLOBAL_MUTEX for (i = 0; i < MAXLOCALTOKENS; i++)
+    LOCK_GLOBAL_MUTEX;
+    for (i = 0; i < MAXLOCALTOKENS; i++)
 	if (local_tokens[i].valid
 	    && (strcmp(local_tokens[i].server.name, aserver->name) == 0)
 	    && (strcmp(local_tokens[i].server.instance, aserver->instance) ==
@@ -830,9 +827,11 @@ GetLocalToken(struct ktc_principal *aserver, struct ktc_token *atoken,
 		   min(atokenLen, sizeof(struct ktc_token)));
 	    memcpy(aclient, &local_tokens[i].client,
 		   sizeof(struct ktc_principal));
-	    UNLOCK_GLOBAL_MUTEX return 0;
+	    UNLOCK_GLOBAL_MUTEX;
+	    return 0;
 	}
-    UNLOCK_GLOBAL_MUTEX return KTC_NOENT;
+    UNLOCK_GLOBAL_MUTEX;
+    return KTC_NOENT;
 }
 
 
@@ -841,12 +840,14 @@ ForgetLocalTokens()
 {
     int i;
 
-    LOCK_GLOBAL_MUTEX for (i = 0; i < MAXLOCALTOKENS; i++) {
+    LOCK_GLOBAL_MUTEX;
+    for (i = 0; i < MAXLOCALTOKENS; i++) {
 	local_tokens[i].valid = 0;
 	memset(&local_tokens[i].token.sessionKey, 0,
 	       sizeof(struct ktc_encryptionKey));
     }
-    UNLOCK_GLOBAL_MUTEX return 0;
+    UNLOCK_GLOBAL_MUTEX;
+    return 0;
 }
 
 
@@ -855,7 +856,8 @@ ForgetOneLocalToken(struct ktc_principal *aserver)
 {
     int i;
 
-    LOCK_GLOBAL_MUTEX for (i = 0; i < MAXLOCALTOKENS; i++) {
+    LOCK_GLOBAL_MUTEX;
+    for (i = 0; i < MAXLOCALTOKENS; i++) {
 	if (local_tokens[i].valid
 	    && (strcmp(local_tokens[i].server.name, aserver->name) == 0)
 	    && (strcmp(local_tokens[i].server.instance, aserver->instance) ==
@@ -864,8 +866,10 @@ ForgetOneLocalToken(struct ktc_principal *aserver)
 	    local_tokens[i].valid = 0;
 	    memset(&local_tokens[i].token.sessionKey, 0,
 		   sizeof(struct ktc_encryptionKey));
-	    UNLOCK_GLOBAL_MUTEX return 0;
+	    UNLOCK_GLOBAL_MUTEX;
+	    return 0;
 	}
     }
-    UNLOCK_GLOBAL_MUTEX return KTC_NOENT;
+    UNLOCK_GLOBAL_MUTEX;
+    return KTC_NOENT;
 }
