@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/stds.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/ubik_db_if.c,v 1.10.14.8 2009/04/27 19:17:27 shadow Exp $");
 
 #include <sys/types.h>
 #include <fcntl.h>
@@ -37,6 +35,7 @@ RCSID
 
 #include "bc.h"
 #include "error_macros.h"
+#include "bucoord_internal.h"
 #include "bucoord_prototypes.h"
 
 extern char *whoami;
@@ -621,6 +620,7 @@ bcdb_SaveTextFile(udbClientTextP ctPtr)
     return (code);
 }
 
+int
 bcdb_FindLastTape(afs_int32 dumpID, struct budb_dumpEntry *dumpEntry,
 		  struct budb_tapeEntry *tapeEntry,
 		  struct budb_volumeEntry *volEntry)
@@ -629,6 +629,7 @@ bcdb_FindLastTape(afs_int32 dumpID, struct budb_dumpEntry *dumpEntry,
 	     tapeEntry, volEntry));
 }
 
+int
 bcdb_MakeDumpAppended(afs_int32 appendedDumpID, afs_int32 initialDumpID,
 		      afs_int32 startTapeSeq)
 {
