@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/budb/database.c,v 1.7.14.5 2009/03/16 13:41:34 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -25,7 +23,7 @@ RCSID
 #include "budb_errs.h"
 #include "database.h"
 #include "error_macros.h"
-#include "budb_prototypes.h"
+#include "budb_internal.h"
 #include "afs/audit.h"
 #include <string.h>
 
