@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/butm/file_tm.c,v 1.12.6.4 2009/03/16 13:45:21 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -31,6 +29,7 @@ RCSID
 #include <afs/butm.h>
 #include <afs/usd.h>
 #include "error_macros.h"
+#include "butm_prototypes.h"
 
 #ifdef O_LARGEFILE
 typedef off64_t osi_lloff_t;
@@ -673,11 +672,11 @@ incPosition(struct butm_tapeInfo *info, usd_handle_t fid, afs_uint32 dataSize)
  */
 afs_int32 TapeBlockSize;
 afs_int32
-readData(usd_handle_t fid, char *data, afs_int32 totalSize, afs_int32 *errorP)
+readData(usd_handle_t fid, char *data, afs_uint32 totalSize, afs_int32 *errorP)
 {
     afs_int32 toread;		/* Number of bytes to read */
-    afs_int32 rSize;		/* Total bytes read so far */
-    afs_int32 tSize;		/* Temporary size */
+    afs_uint32 rSize;		/* Total bytes read so far */
+    afs_uint32 tSize;		/* Temporary size */
     afs_int32 rc;		/* return code */
 
     toread = totalSize;		/* First, try to read all the data */
@@ -776,7 +775,7 @@ WriteTapeBlock(struct butm_tapeInfo *info,
 	       afs_int32 blockType)
 {
     afs_int32 code = 0, rc = 0;
-    afs_int32 wsize;
+    afs_uint32 wsize;
     struct tapeLabel *label;
     struct fileMark *fmark;
     struct blockMark *bmark;
