@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.12 2005/11/05 06:48:06 jaltman Exp $");
 
 #include <sys/types.h>
 #include <ctype.h>
@@ -30,9 +28,9 @@ struct cmd_token {
 static int dummy;		/* non-null ptr used for flag existence */
 static struct cmd_syndesc *allSyntax = 0;
 static int noOpcodes = 0;
-static int (*beforeProc) (struct cmd_syndesc * ts, char *beforeRock) =
-    0, (*afterProc) (struct cmd_syndesc * ts, char *afterRock) = 0;
-static char *beforeRock, *afterRock;
+static int (*beforeProc) (struct cmd_syndesc * ts, void *beforeRock) = NULL;
+static int (*afterProc) (struct cmd_syndesc * ts, void *afterRock) = NULL;
+static void *beforeRock, *afterRock;
 static char initcmd_opcode[] = "initcmd";	/*Name of initcmd opcode */
 
 /* take name and string, and return null string if name is empty, otherwise return
@@ -40,13 +38,14 @@ static char initcmd_opcode[] = "initcmd";	/*Name of initcmd opcode */
 static char *
 NName(char *a1, char *a2)
 {
-    static char tbuffer[80];
+    static char tbuffer[300];
     if (strlen(a1) == 0) {
-	return "";
+        return "";
     } else {
-	strcpy(tbuffer, a1);
-	strcat(tbuffer, a2);
-	return tbuffer;
+        strncpy(tbuffer, a1, sizeof(tbuffer));
+        strncat(tbuffer, a2, sizeof(tbuffer));
+        tbuffer[sizeof(tbuffer)-1]='\0';
+        return tbuffer;
     }
 }
 
@@ -165,6 +164,15 @@ PrintParmHelp(register struct cmd_parmdesc *aparm)
 	printf(" <arg>+");
 }
 
+extern char *AFSVersion;
+
+static int
+VersionProc(register struct cmd_syndesc *as, void *arock)
+{
+    printf("%s\n", AFSVersion);
+    return 0;
+}
+
 void
 PrintSyntax(register struct cmd_syndesc *as)
 {
@@ -263,7 +271,7 @@ PrintFlagHelp(register struct cmd_syndesc *as)
 }
 
 static int
-AproposProc(register struct cmd_syndesc *as, char *arock)
+AproposProc(register struct cmd_syndesc *as, void *arock)
 {
     register struct cmd_syndesc *ts;
     char *tsub;
@@ -288,7 +296,7 @@ AproposProc(register struct cmd_syndesc *as, char *arock)
 }
 
 static int
-HelpProc(register struct cmd_syndesc *as, char *arock)
+HelpProc(register struct cmd_syndesc *as, void *arock)
 {
     register struct cmd_syndesc *ts;
     register struct cmd_item *ti;
@@ -335,8 +343,8 @@ HelpProc(register struct cmd_syndesc *as, char *arock)
 }
 
 int
-cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, char *beforeRock),
-		  char *arock)
+cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, void *beforeRock),
+		  void *arock)
 {
     beforeProc = aproc;
     beforeRock = arock;
@@ -344,8 +352,8 @@ cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, char *beforeRock),
 }
 
 int
-cmd_SetAfterProc(int (*aproc) (struct cmd_syndesc * ts, char *afterRock),
-		 char *arock)
+cmd_SetAfterProc(int (*aproc) (struct cmd_syndesc * ts, void *afterRock),
+		 void *arock)
 {
     afterProc = aproc;
     afterRock = arock;
@@ -371,8 +379,8 @@ SortSyntax(struct cmd_syndesc *as)
 
 struct cmd_syndesc *
 cmd_CreateSyntax(char *aname,
-		 int (*aproc) (struct cmd_syndesc * ts, char *arock),
-		 char *arock, char *ahelp)
+		 int (*aproc) (struct cmd_syndesc * ts, void *arock),
+		 void *arock, char *ahelp)
 {
     register struct cmd_syndesc *td;
 
@@ -472,7 +480,7 @@ cmd_AddParm(register struct cmd_syndesc *as, char *aname, int atype,
     strcpy(tp->name, aname);
     tp->type = atype;
     tp->flags = aflags;
-    tp->items = (struct cmd_item *)0;
+    tp->items = NULL;
     if (ahelp) {
 	tp->help = (char *)malloc(strlen(ahelp) + 1);
 	assert(tp->help);
@@ -547,7 +555,7 @@ ResetSyntax(register struct cmd_syndesc *as)
 	default:
 	    break;
 	}
-	tp->items = (struct cmd_item *)0;
+	tp->items = NULL;
     }
 }
 
@@ -658,6 +666,16 @@ cmd_Dispatch(int argc, char **argv)
 				  "search by help text");
 	    cmd_AddParm(ts, "-topic", CMD_SINGLE, CMD_REQUIRED,
 			"help string");
+	    ts = cmd_CreateSyntax("version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("-version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("-help", HelpProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("--version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("--help", HelpProc, (char *)0,
+				  (char *)CMD_HIDDEN);
 	}
     }
 
