@@ -45,8 +45,10 @@ pragma Off(Prototype_override_warnings);
 #endif */
 
 #define MAX_AFS_INT32 0x7FFFFFFF
+#define MIN_AFS_INT32 (-MAX_AFS_INT32 - 1)
 #define MAX_AFS_UINT32 0xFFFFFFFF
 #define MAX_AFS_INT64 0x7FFFFFFFFFFFFFFFL
+#define MIN_AFS_INT64 (-MAX_AFS_INT64 - 1)
 #define MAX_AFS_UINT64 0xFFFFFFFFFFFFFFFFL
 
 typedef short afs_int16;
@@ -280,11 +282,13 @@ typedef struct afsUUID afsUUID;
  * windows use a different format string
  */
 #ifdef AFS_NT40_ENV
-#define AFS_INT64_FMT "l64d"
-#define AFS_PTR_FMT   "p"
+#define AFS_INT64_FMT "I64d"
+#define AFS_PTR_FMT   "Ip"
+#define AFS_SIZET_FMT "Iu"
 #else
 #define AFS_INT64_FMT "lld"
-#define AFS_PTR_FMT   "x"
+#define AFS_PTR_FMT   "p"
+#define AFS_SIZET_FMT "u"
 #endif
 
 /* Functions to safely cast afs_int32 and afs_uint32 so they can be used in 
@@ -307,12 +311,8 @@ typedef struct afsUUID afsUUID;
 #define hdr_static_inline(x) static inline x
 #endif
 
-#ifdef  AFS_64BIT_ENV
-hdr_static_inline(afs_int32) afs_cast_int32(afs_int32 d) { return (afs_int32) d; }
-hdr_static_inline(afs_uint32) afs_cast_uint32(afs_uint32 d) { return (afs_uint32) d; }
-#else
-hdr_static_inline(long) afs_cast_int32(afs_int32 d) { return (long) d; }
-hdr_static_inline(unsigned long) afs_cast_uint32(afs_uint32 d) { return (unsigned long) d; }
-#endif
+hdr_static_inline(long) afs_printable_int32_ld(afs_int32 d) { return (long) d; }
+
+hdr_static_inline(unsigned long) afs_printable_uint32_lu(afs_uint32 d) { return (unsigned long) d; }
 
 #endif /* OPENAFS_CONFIG_AFS_STDS_H */
