@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/des/read_pssword.c,v 1.17.14.1 2009/03/16 01:34:48 shadow Exp $");
 
 #include <mit-cpyright.h>
 #include <des.h>
@@ -153,7 +151,7 @@ des_read_pw_string(char *s, int maxa, char *prompt, int verify)
     struct termio ttyb;
     FILE *fi;
     char savel, flags;
-    void (*sig) ();
+    void (*sig) (int);
 #endif
 #endif
 #ifdef AFS_NT40_ENV
