@@ -13,21 +13,19 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/read_passwd.c,v 1.6.14.1 2007/10/30 15:16:39 shadow Exp $");
 
 #include <mit-cpyright.h>
-#include <des.h>
 
 #include <stdio.h>
+#include <des.h>
+#include <des_prototypes.h>
 #ifdef	BSDUNIX
 #include <strings.h>
 #include <sys/ioctl.h>
 #include <signal.h>
 #include <setjmp.h>
 #else
-char *strcpy();
-int strcmp();
+#include <string.h>
 #endif
 #if defined(AFS_AIX_ENV)
 #include <signal.h>
@@ -55,10 +53,7 @@ int read_pw_string();
 
 /*** Routines ****************************************************** */
 int
-des_read_password(k, prompt, verify)
-     C_Block *k;
-     char *prompt;
-     int verify;
+des_read_password(C_Block *k, char *prompt, int verify)
 {
     int ok;
     char key_string[BUFSIZ];
@@ -86,9 +81,7 @@ des_read_password(k, prompt, verify)
    */
 
 static int
-good_gets(s, max)
-     char *s;
-     int max;
+good_gets(char *s, int max)
 {
     int l;			/* length of string read */
     if (!fgets(s, max, stdin)) {
@@ -114,14 +107,9 @@ good_gets(s, max)
 #endif
 
 int
-read_pw_string(s, max, prompt, verify)
-     char *s;
-     int max;
-     char *prompt;
-     int verify;
+read_pw_string(char *s, int max, char *prompt, int verify)
 {
     int ok = 0;
-    int len;			/* password length */
 
 #ifdef	BSDUNIX
     jmp_buf old_env;
@@ -242,10 +230,10 @@ read_pw_string(s, max, prompt, verify)
  * this can be static since we should never have more than
  * one set saved....
  */
-static int (*old_sigfunc[NSIG]) ();
+static int (*old_sigfunc[NSIG]) (int);
 
 static
-push_signals()
+push_signals(void)
 {
     register i;
     for (i = 0; i < NSIG; i++)
@@ -253,7 +241,7 @@ push_signals()
 }
 
 static
-pop_signals()
+pop_signals(void)
 {
     register i;
     for (i = 0; i < NSIG; i++)
@@ -261,9 +249,7 @@ pop_signals()
 }
 
 static void
-sig_restore(sig, code, scp)
-     int sig, code;
-     struct sigcontext *scp;
+sig_restore(int sig, int code, struct sigcontext *scp)
 {
     longjmp(env, 1);
 }
@@ -271,7 +257,7 @@ sig_restore(sig, code, scp)
 
 #if	defined(AFS_AIX_ENV) || defined(AFS_SGI_ENV)
 static int
-catch()
+catch(void)
 {
     ++intrupt;
 }
