@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/test/test_getticket.c,v 1.8.4.1 2007/04/10 18:39:52 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -207,12 +205,10 @@ GetTokenLife(name, passwd, expectedLife, match)
     CheckLife(t.endTime, t.startTime, expectedLife, match);
 }
 
-static long
-Main(as, arock)
-     IN struct cmd_syndesc *as;
-     IN char *arock;
+static int
+Main(struct cmd_syndesc *as, void *arock)
 {
-    long code;
+    int code;
     char name[MAXKTCNAMELEN];
     char instance[MAXKTCNAMELEN];
     char newCell[MAXKTCREALMLEN];
@@ -510,7 +506,7 @@ main(argc, argv)
     initialize_ACFG_error_table();
     initialize_KA_error_table();
 
-    ts = cmd_CreateSyntax(0, Main, 0, "Main program");
+    ts = cmd_CreateSyntax(NULL, Main, NULL, "Main program");
     /* 0 */ cmd_AddParm(ts, "-patient", CMD_FLAG, CMD_OPTIONAL,
 			"wait for TGS ticket to age");
     cmd_Seek(ts, 12);
