@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/cfg/cfghost.c,v 1.6.14.2 2009/03/16 13:26:50 shadow Exp $");
 
 #include <afs/stds.h>
 
@@ -638,7 +636,7 @@ cfg_HostSetAfsPrincipal(void *hostHandle,	/* host config handle */
 int ADMINAPI
 cfg_HostSetAdminPrincipal(void *hostHandle,	/* host config handle */
 			  short isFirst,	/* first server in cell flag */
-			  const char *admin,	/* admin principal name */
+			  char *admin,		/* admin principal name */
 			  const char *passwd,	/* admin initial password */
 			  unsigned int afsUid,	/* admin AFS UID */
 			  afs_status_p st)
@@ -997,8 +995,11 @@ cfg_HostPartitionTableAddEntry(void *hostHandle,	/* host config handle */
 			       afs_status_p st)
 {				/* completion status */
     int rc = 1;
-    afs_status_t tst2, tst = 0;
+    afs_status_t tst = 0;
+#ifdef AFS_NT40_ENV
+    afs_status_t tst2;
     cfg_host_p cfg_host = (cfg_host_p) hostHandle;
+#endif
 
 #ifdef AFS_NT40_ENV
     /* validate parameters */
@@ -1068,8 +1069,11 @@ cfg_HostPartitionTableRemoveEntry(void *hostHandle,	/* host config handle */
 				  afs_status_p st)
 {				/* completion status */
     int rc = 1;
-    afs_status_t tst2, tst = 0;
+    afs_status_t tst = 0;
+#ifdef AFS_NT40_ENV
+    afs_status_t tst2;
     cfg_host_p cfg_host = (cfg_host_p) hostHandle;
+#endif
 
 #ifdef AFS_NT40_ENV
     /* validate parameters */
