@@ -21,6 +21,9 @@
 
 #include <pthread.h>
 
+#include <rx/rx.h>
+#include <rx/rxstat.h>
+
 #include <afs/afs_Admin.h>
 #include <afs/afs_clientAdmin.h>
 #include <afs/afs_utilAdmin.h>
@@ -30,4 +33,4 @@
 #include "common.h"
 
 void
-SetupClientAdminCmd(void);
+  SetupClientAdminCmd(void);
