@@ -11,8 +11,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ptserver/db_verify.c,v 1.16.14.8 2009/03/17 04:45:11 shadow Exp $");
 
 /*
  *                      (3) Define a structure, idused, instead of an
@@ -57,10 +55,11 @@ RCSID
 #include "pterror.h"
 #include "ptserver.h"
 #include "ptuser.h"
+#include "display.h"
 
 struct prheader cheader;
 int fd;
-char *pr_dbaseName;
+const char *pr_dbaseName;
 char *whoami = "db_verify";
 #define UBIK_HEADERSIZE 64
 
