@@ -14,8 +14,6 @@
 #include <afs/param.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_packet.c,v 1.62.2.24 2009/01/28 22:33:28 shadow Exp $");
 
 #ifdef KERNEL
 #if defined(UKERNEL)
@@ -61,16 +59,11 @@ RCSID
 #include "sys/types.h"
 #include <sys/stat.h>
 #include <errno.h>
-#if defined(AFS_NT40_ENV) || defined(AFS_DJGPP_ENV)
-#ifdef AFS_NT40_ENV
+#if defined(AFS_NT40_ENV)
 #include <winsock2.h>
 #ifndef EWOULDBLOCK
 #define EWOULDBLOCK WSAEWOULDBLOCK
 #endif
-#else
-#include <sys/socket.h>
-#include <netinet/in.h>
-#endif /* AFS_NT40_ENV */
 #include "rx_user.h"
 #include "rx_xmit_nt.h"
 #include <stdlib.h>
@@ -111,12 +104,13 @@ static void rxi_SendDebugPacket(struct rx_packet *apacket, osi_socket asocket,
 				afs_int32 ahost, short aport,
 				afs_int32 istack);
 
-static int rxi_FreeDataBufsToQueue(struct rx_packet *p, 
-				   afs_uint32 first, 
-				   struct rx_queue * q);
 #ifdef RX_ENABLE_TSFPQ
 static int
 rxi_FreeDataBufsTSFPQ(struct rx_packet *p, afs_uint32 first, int flush_global);
+#else
+static int rxi_FreeDataBufsToQueue(struct rx_packet *p,
+				   afs_uint32 first,
+				   struct rx_queue * q);
 #endif
 
 /* some rules about packets:
@@ -2290,10 +2284,10 @@ rxi_SendPacket(struct rx_call *call, struct rx_connection *conn,
 	     */
 	    if (call && 
 #ifdef AFS_NT40_ENV
-		code == -1 && WSAGetLastError() == WSAEHOSTUNREACH
-#elif defined(AFS_LINUX20_ENV) && defined(KERNEL)
+		(code == -1 && WSAGetLastError() == WSAEHOSTUNREACH) || (code == -WSAEHOSTUNREACH)
+#elif defined(AFS_LINUX20_ENV)
 		code == -ENETUNREACH
-#elif defined(AFS_DARWIN_ENV) && defined(KERNEL)
+#elif defined(AFS_DARWIN_ENV)
 		code == EHOSTUNREACH
 #else
 		0
@@ -2480,10 +2474,10 @@ rxi_SendPacketList(struct rx_call *call, struct rx_connection *conn,
 	     */
 	    if (call && 
 #ifdef AFS_NT40_ENV
-		code == -1 && WSAGetLastError() == WSAEHOSTUNREACH
-#elif defined(AFS_LINUX20_ENV) && defined(KERNEL)
+		(code == -1 && WSAGetLastError() == WSAEHOSTUNREACH) || (code == -WSAEHOSTUNREACH)
+#elif defined(AFS_LINUX20_ENV)
 		code == -ENETUNREACH
-#elif defined(AFS_DARWIN_ENV) && defined(KERNEL)
+#elif defined(AFS_DARWIN_ENV)
 		code == EHOSTUNREACH
 #else
 		0
