@@ -35,8 +35,6 @@
 #include <string.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/xdr.c,v 1.11.4.2 2009/01/28 22:33:28 shadow Exp $");
 
 /*
  * xdr.c, Generic XDR routines implementation.
@@ -583,4 +581,16 @@ xdr_wrapstring(XDR * xdrs, char **cpp)
     return (FALSE);
 }
 #endif
+
+void *
+xdr_alloc(afs_int32 size)
+{
+    return osi_alloc(size);
+}
+
+void
+xdr_free(void *x, afs_int32 size)
+{
+    osi_free(x, size);
+}
 #endif /* NeXT */
