@@ -19,11 +19,7 @@ extern int ioctl_afs_syscall(long, long, long, long, long, long, long, int *);
 #endif
 
 /* pioctl.c */
-extern int lpioctl(char *, int, char *, int);
-
-/* rmtsys.ss.c */
-struct rx_call;
-extern int RMTSYS_ExecuteRequest(struct rx_call *);
+extern int lpioctl(char *, int, void *, int);
 
 /* rmtsysc.c */
 struct ViceIoctl;
