@@ -18,8 +18,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/vol/fssync-debug.c,v 1.1.4.10 2009/03/17 15:10:58 shadow Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -42,7 +40,6 @@ RCSID
 #include <afs/afsint.h>
 #include <afs/assert.h>
 
-
 #include <fcntl.h>
 
 #ifndef AFS_NT40_ENV
@@ -50,6 +47,7 @@ RCSID
 #endif
 
 #include <afs/cmd.h>
+#include <afs/dir.h>
 #include <afs/afsutil.h>
 #include <afs/fileutil.h>
 
@@ -898,7 +896,7 @@ VolOpQuery(struct cmd_syndesc * as, void * rock)
 	printf("\t\treason         = %d (%s)\n", 
 	       vop.com.reason, reason_code_to_string(vop.com.reason));
 	printf("\t\tcommand_len    = %u\n", vop.com.command_len);
-	printf("\t\tflags          = 0x%lux\n", afs_cast_uint32(vop.com.flags));
+	printf("\t\tflags          = 0x%lux\n", afs_printable_uint32_lu(vop.com.flags));
 	printf("\t}\n");
 
 	printf("\tvop = {\n");
@@ -1075,7 +1073,7 @@ VnQuery(struct cmd_syndesc * as, void * rock)
 	printf("\t\tserverModifyTime  = %u\n", v.disk.serverModifyTime);
 	printf("\t\tgroup             = %d\n", v.disk.group);
 	printf("\t\tvn_ino_hi         = %d\n", v.disk.vn_ino_hi);
-	printf("\t\treserved6         = %u\n", v.disk.reserved6);
+	printf("\t\tvn_length_hi      = %u\n", v.disk.vn_length_hi);
 	printf("\t}\n");
 
 	printf("}\n");
