@@ -10,13 +10,22 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/volser/common.c,v 1.10 2003/11/15 04:59:16 shadow Exp $");
-
 #include <stdio.h>
+#include <stdlib.h>
+
 #include <afs/afsutil.h>
 #include <afs/com_err.h>
 
+#ifndef AFS_PTHREAD_ENV
+#include <afs/kautils.h>
+#include <rx/rxkad.h>
+#include <afs/auth.h>
+#include <afs/cellconfig.h>+
+#include <afs/cmd.h>
+#include <afs/vlserver.h>
+#include "volser.h"
+#endif
+
 #ifndef AFS_PTHREAD_ENV
 /*@printflike@*/ void
 Log(const char *format, ...)
@@ -33,7 +42,7 @@ void
 LogError(afs_int32 errcode)
 {
     ViceLog(0,
-	    ("%s: %s\n", error_table_name(errcode), error_message(errcode)));
+	    ("%s: %s\n", afs_error_table_name(errcode), afs_error_message(errcode)));
 }
 
 #ifndef AFS_PTHREAD_ENV
